var AVActionOverview = AVTab2.extend({
   
   // Overloaded in avtreetab.js.
   events: {
      // For tab navigation links.
      "click .operation .pianoButton.nav" : "clickNavButton",
      // For action buttons.
      "click .operation .pianoButton.action": "clickActionButton",
      // For "View more details" link.
      "click #viewMoreDetails": "clickViewMoreDetails",
      // For "View all status messages" link.
      "click #viewStatusMessages": "clickViewStatusMessages"
   },

   // 4. Triggered by AVTab1
   refresh: function()
   {
      // oDevice will be out of date upon refresh, so clear it.
      this.model.set('oDevice', null);
      // Do not need to refresh the following objects because
      // render will redraw everything with updated info already.
      //this.addToRefreshQueue(this.oVDeviceStatus);
      //this.addToRefreshQueue(this.oVDeviceConfigSummary);
      //this.executeRefreshQueue();
      this.postRefresh();
   },

   postRefresh: function() {
      this.render();
      this.resize();
      AVTab2.prototype.postRefresh.call(this);
   },

   dispose: function() {
      if (IsDefined(this.oVDeviceStatus))
      {
         this.oVDeviceStatus.dispose();
      }
      if (IsDefined(this.oVDeviceConfigSummary))
      {
         this.oVDeviceConfigSummary.dispose();
      }
      AVTab2.prototype.dispose.call(this);
   },
   
   render: function ()
   {
      // Same as AVAction
      $(this.el).empty();
      // Content header is used for page resizing.
      var oOpHeaderDiv = $('<div/>', {'class':"opHeader"});
      var oOpBodyDiv = $('<div/>', {
         'class':"opBody"
      });
      var oOpBodyInnerDiv = $('<div/>', {
         'class':"opBodyInner"
      });
      var oOpBodyWidthDiv = $('<div/>', {'class': 'opBodyWidth'});
      var oNotesDiv = $('<div/>', {
         'class': 'notes'
      });
      
      oOpBodyDiv.append(oOpBodyInnerDiv);
      oOpBodyDiv.append(GetClearFloatsDiv());
      oOpBodyInnerDiv.append(oOpBodyWidthDiv);
      oOpBodyInnerDiv.append(oNotesDiv);
      $(this.el).append(oOpHeaderDiv);
      $(this.el).append(oOpBodyDiv);

      //AVAction.prototype.render.call(this);
      this.drawAll();
      return this;
   },
   
   // Overload to customize.
   drawAll: function()
   {
      this.drawHeader();
      // Draw widgets on dashboard.
      var oBodyDiv = this.$('.opBodyInner');
      this.drawLeftColumn(oBodyDiv);
      this.drawRightColumn(oBodyDiv);
   },
   
   drawColumnWidget: function(oParentDiv, sID)
   {
      var oDiv = $('<div/>', {'id': sID, 'class':'columnWidget'});
      oParentDiv.append(oDiv);
      return oDiv;
   },
   
   drawLeftColumn: function(oParentDiv)
   {
      var oColumnDiv = $('<div/>', {'class':'leftColumn action'});
      oParentDiv.append(oColumnDiv);
      this.drawActionWidget(oColumnDiv);
   },
   
   drawRightColumn: function(oParentDiv)
   {
      var oColumnDiv = $('<div/>', {'class':'rightColumn'});
      oParentDiv.append(oColumnDiv);
      
      // Status
      //this.drawStatusWidget(oColumnDiv);
      
      // Configuration Summary
      //this.drawConfigWidget(oColumnDiv);
   },
   
   // When an action is clicked in an Overview (two-pane) page.
   clickNavButton: function(e)
   {
      NavigateTo(($(e.currentTarget).attr("rel")), true, false, true);
      return false;
   },
   
   // Draws the tab navigation button DOM element.
   getTabEl: function(sPath, sButtonLabel, sDescription, bIsLastAction)
   {
      var sOperationClass = "operation";
      if (IsDefined(bIsLastAction) && bIsLastAction)
      {
         sOperationClass += " last";
      }
      var oTabDiv = $('<div/>', { 'class': sOperationClass });
      var oButtonDiv = $('<a/>', { 'href':'', 'class': "pianoButton default nav", 'rel': sPath });
      oButtonDiv.html(TranslateString(sButtonLabel));
      oTabDiv.append(oButtonDiv);
      oTabDiv.append(GetClearFloatsDiv());
      var oDescDiv = $('<div/>', {'class':'description'});
      oDescDiv.append(TranslateString(sDescription));
      oTabDiv.append(oDescDiv);
      return oTabDiv;
   },

   // Draws the action button DOM element.
   getActionEl: function(sButtonLabel, sButtonName, sDescription, bIsLastAction)
   {
      var sOperationClass = "operation";
      if (IsDefined(bIsLastAction) && bIsLastAction)
      {
         sOperationClass += " last";
      }
      var oTabDiv = $('<div/>', { 'class': sOperationClass });
      //var sClass = "pianoButton default button combined Execute";
      var sClass = "pianoButton default button action";
      var oButtonDiv = $('<a/>', {
         'href': '',
         'id': sButtonName,
         'class': sClass
      });
      oButtonDiv.html(TranslateString(sButtonLabel));
      oTabDiv.append(oButtonDiv);
      oTabDiv.append(GetClearFloatsDiv());
      var oDescDiv = $('<div/>', {'class':'description'});
      oDescDiv.append(TranslateString(sDescription));
      oTabDiv.append(oDescDiv);
      return oTabDiv;
   },

   // Add navigation tabs.
   addNavButtons: function(oActions, oParentDiv)
   {
      for (var i=0; i<oActions.length; ++i)
      {
         var bIsLastAction = i == oActions.length-1;
         oParentDiv.append(
            this.getTabEl(
               oActions[i].sLink,
               oActions[i].sLabel,
               oActions[i].sHint,
               bIsLastAction
         ));
      }
   },

   // Action buttons will trigger this method. (e.g. Create Array)
   // Currently only used by AVTreeTab.
   clickActionButton: function(e) {
      $(e.currentTarget).blur();
      var sDeviceID = this.model.get("sDeviceID");
      // Get action details.
      var sActionName = e.currentTarget.id;
      var oOpDetails = GetOperationDetails(sActionName,sDeviceID).operationDetails;
      // Display the action operation page in a popup.
      var oMConfigAction = new MConfigAction({
         'sDeviceID': this.model.get('sDeviceID'),
         'oOpDetails':oOpDetails,
         'bIsCombinedOp': false
      });
      var oVConfigAction = new VConfigAction({
         'model':oMConfigAction
      });
      this.$el.trigger("popup", {
         'sType': 'actionConfigPopup',
         'oVContent': oVConfigAction
      });
      
      // TODO: Is this needed?
      oVConfigAction.resize();

      return false;
   },

   drawBox: function(oParentDiv)
   {
      var oBoxWrapper = $('<div/>', {'class': 'boxWrapper'});
      var oBox = $('<div/>', {'class': 'box'});
      oBoxWrapper.append(oBox);
      oParentDiv.append(oBoxWrapper);
      return oBox;
   },

   drawWidgetTitle: function(oParentDiv, sTitle)
   {
      var oTitle = $('<div/>', {'class': 'title'});
      oTitle.append(TranslateString(sTitle));
      oParentDiv.append(oTitle);
      oParentDiv.append(GetClearFloatsDiv());
   },

   // oParentDiv - div to draw action widget in.   
   // bHideNoActions - true to hide widget when no actions exist.
   drawActionWidget: function(oParentDiv, bHideNoActions)
   {
      var oOperationSelectionDiv = $('<div/>', { 'class': "operationSelection" });
      var nNumActions = this.drawActions(oOperationSelectionDiv);
      if (!bHideNoActions || nNumActions > 0)
      {
         var oWidgetDiv = this.drawColumnWidget(oParentDiv, "actionsWidget");
         var oBox = this.drawBox(oWidgetDiv);
         this.drawWidgetTitle(oBox, "STR_ACTIONS");
         oBox.append(oOperationSelectionDiv);
         // If no Actions were drawn, display message.
         if (nNumActions == 0)
         {
            var oNoteDiv = $('<div/>', {'class':'note'});
            oNoteDiv.append(TranslateString("STR_NO_ACTIONS"));
            oOperationSelectionDiv.append(oNoteDiv);
         }
      }
      return nNumActions;
   },

   // Returns the number of Actions drawn.
   /*drawNavActions: function(oParentDiv)
   {
      // Overload if custom Actions are needed or if no path is needed.
      var oOpGroups = this.model.get('oOperations');
      var sLinkPath = this.model.get('sLinkPath');
      var nNumOpGroups = oOpGroups.length;
      for (var j = 0; j < nNumOpGroups; ++j)
      {
         var oList = oOpGroups[j].OperationList;
         var oHintList = oOpGroups[j].HintList;
         var sGroupName = oOpGroups[j].GroupName;
         // Hide group names if there is only one group.
         // Do not show "Default Group".
         if (sGroupName != "Default Group" && nNumOpGroups > 1)
         {
            var oGroupLabelDiv = $('<div/>', {'class':'groupLabel'});
            oGroupLabelDiv.append(TranslateString(sGroupName));
            oParentDiv.append(oGroupLabelDiv);
         }
         for (var i = 0; i < oList.length; ++i)
         {
            var sPath = sLinkPath + oList[i];
            var sButtonLabel = TranslateString(oList[i]);
            var sDescription = TranslateString(oHintList[i]);
            var bIsLastAction = i == oList.length-1;
            var oTabDiv = this.getTabEl(sPath, sButtonLabel, sDescription, bIsLastAction);
            oParentDiv.append(oTabDiv);
         }
      }
      return nNumOpGroups;
   },*/

   // To overload.
   drawActions: function(oParentDiv)
   {
      var sDeviceID = this.model.get("sDeviceID");
      var sType = this.model.get("sType");

      // Operations are organized into groups.
      var oOpGroups = GetOperations(sType, sDeviceID).operations;
      var nNumOpGroups = oOpGroups.length;
      var nNumActions = 0;

      for (var i = 0; i < nNumOpGroups; ++i)
      {
         var oList = oOpGroups[i].OperationList;
         var sGroupName = oOpGroups[i].GroupName;
         // Hide group names if there is only one group.
         // Do not show "Default Group".
         if (sGroupName != "Default Group" && nNumOpGroups > 1)
         {
            var oGroupLabelDiv = $('<div/>', {'class':'groupLabel'});
            oGroupLabelDiv.append(TranslateString(sGroupName));
            oParentDiv.append(oGroupLabelDiv);
         }
         for (var j = 0; j < oList.length; ++j)
         {
            var sButtonLabel = oList[j].Label;
            var sButtonName = oList[j].Name;
            var sDescription = oList[j].Hint;
            //var bIsLastAction = i == nNumOpGroups-1 && j == oList.length-1;
            var bIsLastAction = j == oList.length-1;
            var oTabDiv = this.getActionEl(sButtonLabel, sButtonName, sDescription, bIsLastAction);
            oParentDiv.append(oTabDiv);
            nNumActions++;
         }
      }
      return nNumActions;
   },

   drawDetailsWidget: function(oParentDiv, sDisplayedDetails)
   {
      var oWidgetDiv = this.drawColumnWidget(oParentDiv, "detailsWidget");
      var oBox = this.drawBox(oWidgetDiv);
      var oDetails = sDisplayedDetails.split("|");
      var oDeviceDetailsDiv = $('<div/>', {
         'class':'deviceDetails'
      });
      for (var i=0; i<oDetails.length; ++i) {
         var oMDeviceDetails = new MDeviceDetails({
         'sDeviceID':this.model.get('sDeviceID'),
         'sDetails':oDetails[i]
         });
         var oVDeviceDetails = new VDeviceDetails({
            'el':oDeviceDetailsDiv,
            'model':oMDeviceDetails
         });
      }
      // Add View More Details link.
      var oDetailsLink = $('<a/>', {
         'href':'',
         'class':'widgetLink',
         'id':'viewMoreDetails'
      });
      oDetailsLink.append(TranslateString("STR_VIEW_MORE_DETAILS"));
      oDeviceDetailsDiv.append(oDetailsLink);
      oBox.append(oDeviceDetailsDiv);
   },
   
   drawStatusWidget: function(oParentDiv)
   {
      var oWidgetDiv = this.drawColumnWidget(oParentDiv, "statusWidget");
      var oBox = this.drawBox(oWidgetDiv);
      this.drawWidgetTitle(oBox, "STR_STATUS_MESSAGES");
      var oMDeviceStatus = new MDeviceStatus({
         'sDeviceID':this.model.get('sDeviceID'),
         'oDevice':this.model.get('oDevice'),
         'nDetailLevel':1
      });
      this.oVDeviceStatus = new VDeviceStatus({
         'model':oMDeviceStatus
      });
      oBox.append(this.oVDeviceStatus.$el);
   },
   
   // This is only good for Controller Configuration right now.
   // Modify in order to use for other devices/managers.
   drawConfigWidget: function(oParentDiv)
   {
      var oMDeviceConfigSummary = new MDeviceConfigSummary({
         'sDeviceID':this.model.get('sDeviceID'),
         'oDevice':this.model.get('oDevice'),
         'bConfigSummaryExists':true
      });
      this.oVDeviceConfigSummary = new VDeviceConfigSummary({
         'model':oMDeviceConfigSummary
      });
      var bConfigSummaryExists = this.oVDeviceConfigSummary.model.get('bConfigSummaryExists');
      if (bConfigSummaryExists)
      {
         var oWidgetDiv = this.drawColumnWidget(oParentDiv, "configWidget");
         var oBox = this.drawBox(oWidgetDiv);
         this.drawWidgetTitle(oBox, "STR_CONTROLLER_CONFIGURATION");
         oBox.append(this.oVDeviceConfigSummary.$el);
      }
      // Display Hardware Info for HBA Mode if Configuration Summary DNE
      else
      {
         this.drawDetailsWidget(oParentDiv, "STR_CONTROLLER_HARDWARE_INFO");
      }
   },
   
   clickViewMoreDetails: function(e) {
      $(e.currentTarget).blur();
      var oMDetailsPopup = new MDetailsPopup({
         'sDeviceID': this.model.get('sDeviceID'),
         'oDevice': this.model.get('oDevice'),
         'bIncludeStatusAlerts': this.model.get("bIncludeStatusAlerts")
      });
      var oVDetailsPopup = new VDetailsPopup({
         'model': oMDetailsPopup
      });
      this.$el.trigger("popup", {
         'sType': 'detailsPopup',
         'oVContent': oVDetailsPopup,
         'bClickOutsideToClose':true
      });
      return false;
   },
   
   clickViewStatusMessages: function(e) {
      $(e.currentTarget).blur();
      var oMStatusPopup = new MStatusPopup({
         'sDeviceID': this.model.get('sDeviceID'),
         'oDevice': this.model.get('oDevice')
      });
      var oVStatusPopup = new VStatusPopup({
         'model': oMStatusPopup
      });
      this.$el.trigger("popup", {
         'sType': 'statusPopup',
         'oVContent': oVStatusPopup,
         'bClickOutsideToClose':true
      });
      return false;
   },
   
   resizeWidth: function() {
      AVTab2.prototype.resizeWidth.call(this);
      var oLeftColumnDiv = this.$('.leftColumn');
      var oRightColumnDiv = this.$('.rightColumn');
      var oOpBodyWidthDiv = this.$('.opBodyWidth');
      var nBodyWidth = oOpBodyWidthDiv.width();
      var nRightColumnMargin = parseInt(oRightColumnDiv.css('margin-left')) + parseInt(oRightColumnDiv.css('margin-right'));;
      var nRightColumnWidth = nBodyWidth - oLeftColumnDiv.outerWidth(true) - nRightColumnMargin;
      oRightColumnDiv.width(nRightColumnWidth);
   },
   
   resizeHeight: function() {
      // Make sure left column does not exceed height of the body so that it would have its own vertical scrollbar.
      AVTab2.prototype.resizeHeight.call(this);

      // From AVAction
      var oOpHeaderDiv = this.$('.opHeader');
      var oOpFooterDiv = this.$('.opFooter');
      var nHeight = this.model.get('nHeight');
      var nHeaderHeight = IsDefinedAndSet(oOpHeaderDiv.outerHeight()) ? oOpHeaderDiv.outerHeight() : 0;
      var nFooterHeight = IsDefinedAndSet(oOpFooterDiv.outerHeight()) ? oOpFooterDiv.outerHeight() : 0;
      var nOpBodyDivHeight = nHeight - nHeaderHeight - nFooterHeight;
      var oOpBodyDiv = this.$('.opBody');
      oOpBodyDiv.height(nOpBodyDivHeight);
      /*var nNoteWidth = this.$('.notes').width();
      if (nNoteWidth != this.model.get('nNoteWidth'))
      {
         this.resizeWidth();
      }*/
      // End AVAction

      var oActionsDiv = this.$('#actionsWidget');
      var oInnerColumnDiv = this.$('#actionsWidget .box');
      var nInnerColumnHeight = oInnerColumnDiv.outerHeight(true);
      var nBodyHeight = oOpBodyDiv.height();
      var oMarginBtm = parseInt(oActionsDiv.css('margin-bottom'));
      var oMarginTop = parseInt(oActionsDiv.css('margin-top'));
      var oBorderBtm = parseInt(oActionsDiv.css('border-bottom-width'));
      var oBorderTop = parseInt(oActionsDiv.css('border-top-width'));
      var nMaxColumnHeight;
      var oLeftColumnDiv = this.$('.leftColumn');
      var oRightColumnDiv = this.$('.rightColumn');
      var nLeftColumnHeight = oLeftColumnDiv.height();
      var nRightColumnHeight = oRightColumnDiv.height();
      // When left column is not longer than right column (meaning no scrollbar on left column)
      // and right column is longer than the parent height (meaning scrollbar on parent body),
      if (nLeftColumnHeight <= nRightColumnHeight && nRightColumnHeight > nBodyHeight)
      {
         nMaxColumnHeight = nRightColumnHeight - oMarginBtm - oMarginTop - oBorderBtm - oBorderTop;
         oActionsDiv.height(nMaxColumnHeight);
      }
      else
      {
         nMaxColumnHeight = nBodyHeight - oMarginBtm - oMarginTop - oBorderBtm - oBorderTop;
         // TODO: Set min-height.
         if (nInnerColumnHeight > nMaxColumnHeight)
         {
            oActionsDiv.height(nMaxColumnHeight);
         }
         else
         {
            oActionsDiv.css('height', '');
         }
      }
      // Resize Width to fix the issues where the reappearing scrollbar
      // would cause the main width to be smaller.
      // This line is required for firefox.
      // Other browsers only need this inside the else conditional above.
      this.resizeWidth();
   }

});