var AVTreeNav = AVNav.extend({
   
   events: {
      "change select#TreeFilterSelect" : "onFilterValueChanged",
      "change select#TreeGroupSelect" : "onGroupChanged",
      "change select#TreeSortListSelect" : "onSortListChanged"
   },
   
   // Called by AVTreeActions.
   refresh: function() {
      this.model.refresh();
      this.resize();
   },
   
   initialize: function() {
      AVNav.prototype.initialize.call(this);
      this.render();
      this.model.on("render", this.render, this);
      this.model.on("renderNotifyRefreshObservers", this.renderNotifyRefreshObservers, this);
   },
   
   render: function() {
      AVNav.prototype.render.call(this);
      // Remove tree body div.
      this.$('.treeBody').remove();
      var oFilter = this.model.get('oFilter');
      if (oFilter.isValidFilter())   
      {
         var oFilterMenuDiv = $('<div/>', {'class': "filterMenu"});
         var oFilterGroupsDiv = $('<div/>', {'class': "filterGroups"});
         var oTreeBodyDiv = $('<div/>', {'class': "treeBody"});
         // Add ruler to measure treeBody's displayable width (includes scrollbar if visible).
         var oRulerDiv = $('<div/>', {'class': 'ruler'});
         oTreeBodyDiv.append(oRulerDiv);
         oTreeBodyDiv.append(oFilterGroupsDiv);
         this.$el.append(oTreeBodyDiv);
         this.$('.header .filterMenu').remove(); // Clean up any old menus.
         this.$('.header').append(oFilterMenuDiv);
         this.drawMenu();
         this.drawDevices(); // calls highlightChild()
      }
      // Empty any contents in the notes div.
      this.$('.notes').empty();
      if (this.getNumDevices() == 0)
      {
         this.addNote(this.model.get('sEmptyMsg'));
      }
      // Todo: prevent this from triggering when not actually refreshing.
      //this.trigger("refreshCompleted");
      var oSelectedChild = this.getChild(this.getSelectedDeviceID(), this.getSelectedDeviceParentID());
      if (IsDefined(oSelectedChild))
      {
         var oTB = this.$('.treeBody');
         var nParentTop = oTB.position().top;
         var nChildTop = oSelectedChild.position().top;
         var nScrollTo = nChildTop - nParentTop;
         this.$('.treeBody').scrollTop(nScrollTo);
      }
      return this;
   },
   
   addNote: function(sNote) {
      var oNotesDiv = this.$('.notes');
      var oNoteDiv = $('<div/>', {'class':'note'});
      oNoteDiv.append(TranslateString(sNote));
      oNotesDiv.append(oNoteDiv);
   },

   getSelectedDeviceID: function() {
      return this.model.get('sSelectedDeviceID');
   },

   getSelectedDeviceParentID: function() {
      return this.model.get('sSelectedDeviceParentID');
   },

   getDefaultID: function() {
      // For now, the default ID is just the first device in oDevices.
      // Currently only License Manager uses this to always have a license feature selected.
      var oDevices = this.model.get('oDevices');
      return oDevices.length > 0 ? oDevices[0] : null;
   },

   selectChild: function(sID, sParentID) {
      if (!IsDefinedAndSet(sID))
      {
         sID = this.getSelectedDeviceID();
         sParentID = this.getSelectedDeviceParentID();
      }
      else
      {
         this.model.set({
            'sSelectedDeviceID':sID,
            'sSelectedDeviceParentID':sParentID
         });
      }
      this.highlightChild(sID, sParentID);
      //ClearDeviceSelection();
      var oResponse = SelectDevice(sID);
      return oResponse.SelectStatus == "True";
   },

   getChild: function(sID, sParentID)
   {
      var oSelectable = this.$('.selectable');
      var bFound = false;
      var oChild;
      for (var i=0; !bFound && i<oSelectable.length; ++i)
      {
         var oSelector = this.$(oSelectable[i]);
         bFound = oSelector.attr("id") == sID;
         // Check if parent matches.
         if (IsDefinedAndSet(sParentID))
         {
            bFound = bFound && oSelector.attr("rel") == sParentID;
         }
         if (bFound)
         {
            oChild = oSelector;
         }
      }
      return oChild; 
   },

   highlightChild: function(sID, sParentID) {
      if (!IsDefinedAndSet(sID))
      {
         sID = this.getSelectedDeviceID();
         sParentID = this.getSelectedDeviceParentID();
      }
      var oChild = this.getChild(sID, sParentID);
      if (IsDefined(oChild))
      {
         this.clearSelected();
         oChild.addClass("selected");
      }
   },
   
   clearSelected: function() {
      this.$('.selectable').removeClass('selected');
   },
   
   drawMenu: function() {
      var oDevices = this.model.get('oDevices');
      // Don't add menu if there aren't any devices.
      if (oDevices.length > 0)
      {
         var oFilter = this.model.get('oFilter');
         // Draw Filter Menu.
         var oFilterMenuDiv = this.$('.filterMenu');
         var nNumFilterValues = oFilter.numFilterValues();
         var selectedIndex = 0;
         var selectedValue = GetStoredValue( "TreeFilterSelect" );
         if (nNumFilterValues > 0)
         {
            // Show a filter dropdown.
            var filterName = oFilter.filterName();
            
            // Add filter dropdown label.
            var oFilterSelectLabelSpan = $('<span/>', {'class': 'label'});
            oFilterSelectLabelSpan.html(TranslateString(filterName));
            oFilterMenuDiv.append(oFilterSelectLabelSpan);
            
            // Add filter dropdown.
            var oFilterSelect = $('<select/>', { 'id': 'TreeFilterSelect'});
            for ( var fvIndex = 0; fvIndex < nNumFilterValues; fvIndex++ )
            {
               oFilter.SelectFilterValue( fvIndex );
               var filterValueName = oFilter.filterValueName();		 
               var oOption = $('<option/>', { 'value': filterValueName});
               if ( selectedValue == filterValueName )
               {
                  selectedIndex = fvIndex;
                  oOption = $('<option/>', { 'value': filterValueName, 'selected' : true});
               }
               oOption.html(TranslateString(filterValueName));
               oFilterSelect.append(oOption);
            }
            if (nNumFilterValues == 1)
            {
               oFilterSelectLabelSpan.hide();
               oFilterSelect.hide();
            }
            oFilterMenuDiv.append(oFilterSelect);
         }
         // Show the group by dropdown.
         oFilter.SelectFilterValue(selectedIndex);
         
         // Add group by dropdown label.
         var oGroupBySelectLabelSpan = $('<span/>', {'class': 'label'});
         oGroupBySelectLabelSpan.html(TranslateString("STR_GROUP_BY"));
         
         // Add group by dropdown.
         var oGroupBySelect = $('<select/>', {id: 'TreeGroupSelect'});
         var nNumGroups = oFilter.numGroups();
         // If more than one group by method, use the first non-"none" one.
         var nDefaultGroup = 0;
         if (nNumGroups > 1)
         {
            nDefaultGroup = 1;
         }
         for ( var gIndex = 0; gIndex < nNumGroups; ++gIndex )
         {
            oFilter.SelectGroup( gIndex );
            var groupName = oFilter.groupName();
            var oOption = $('<option/>', {value: groupName});
            oOption.html(TranslateString(groupName));
            if (gIndex == nDefaultGroup)
            {
               oOption.prop('selected', 'selected');
            }
            oGroupBySelect.append(oOption);
         }
         if (nNumGroups == 1)
         {
            oGroupBySelect.prop('disabled', 'disabled');
            // Hide Group By
            oGroupBySelect.css('display', 'none');
         }
         else
         {
            oFilterMenuDiv.append(oGroupBySelectLabelSpan);
         }
         oFilterMenuDiv.append(oGroupBySelect);
         
         // Show the sort by dropdown
         oFilter.SelectGroup( nDefaultGroup );
         oFilter.SelectGroupValue( 0 );
         
         // Add sort by dropdown label.
         var oSortBySelectLabelSpan = $('<span/>', {'class': 'label'});
         oSortBySelectLabelSpan.html(TranslateString("STR_SORT_BY"));
         
         // Add sort by dropdown.
         var oSortBySelect = $('<select/>', {id: 'TreeSortListSelect'});
         var nNumSortLists = oFilter.numSortLists();
         for ( var lIndex = 0; lIndex < nNumSortLists; ++lIndex )
         {
            oFilter.SelectSortList( lIndex );
            var sortListName = oFilter.sortListName();
            var oOption = $('<option/>', {value: sortListName});
            oOption.html(TranslateString(sortListName));
            oSortBySelect.append(oOption);
         }
         if (nNumSortLists == 1)
         {
            oSortBySelect.prop('disabled', 'disabled');
            // Hide Sort By
            oSortBySelect.css('display', 'none');
         }
         else
         {
            oFilterMenuDiv.append(oSortBySelectLabelSpan);
         }
         oFilter.SelectSortList( 0 );
         oFilterMenuDiv.append(oSortBySelect);
      }
   },
   
   drawDevices: function() {
      var oFilter = this.model.get('oFilter');
      var oFilterGroupsDiv = this.$('.filterGroups').empty();
      var oDevices = this.model.get('oDevices');
      var oCurrentValues = this.model.get('oAttributes');
      if (IsDefined(oCurrentValues))
      {
         oCurrentValues = oCurrentValues.CURRENT_VALUE;
         if (IsDefined(oCurrentValues))
         {
            oCurrentValues = oCurrentValues.split('|');
         }
      }
      for ( var gvIndex = 0; gvIndex < oFilter.numGroupValues(); ++gvIndex )
      {
         oFilter.SelectGroupValue( gvIndex );
         oFilter.SelectSortList();
         var oSortList = oFilter.sortList();
         var sGroupName = oFilter.groupName();
         var sGroupValueName = oFilter.groupValueName();
         var sControlName = "Control Name goes here";//this.getName();
         var sGroupID = 'filterGroup' + gvIndex;
         //var oCurrentValues = this.model.get('oCurrentValues');
         var sType = this.model.get('sType');
         var oMTreeDeviceSelectorGroup = new MTreeDeviceSelectorGroup({
            'oSortList':oSortList,
            'sGroupName':sGroupName,
            'sGroupValueName':sGroupValueName,
            'sControlName':sControlName,
            'oDevices':oDevices,
            'oCurrentValues':oCurrentValues,
            'sType':sType
         });
         var oVTreeDeviceSelectorGroup = new VTreeDeviceSelectorGroup({
            'id':sGroupID,
            'model':oMTreeDeviceSelectorGroup
         });
         oFilterGroupsDiv.append(oVTreeDeviceSelectorGroup.$el);
      }
      // Highlight selected.
      this.highlightChild();
      this.resize();
   },
   
   onFilterValueChanged: function(e) {
      this.updateFilter(e.currentTarget.selectedIndex);
      var key = e.currentTarget.id;
      var value = e.currentTarget.value;
      StoreValue( key, value );
   },
   
   updateFilter: function(nSelectedIndex) {
      var oFilter = this.model.get('oFilter');
      oFilter.SelectFilterValue( nSelectedIndex );
      // Update the Group by dropdown since filter has changed.
      var groupSelector = document.getElementById("TreeGroupSelect");
      groupSelector.options.length = 0;
      for ( var i = 0; i < oFilter.numGroups(); ++i )
      {
         oFilter.SelectGroup( i );
         var groupName = oFilter.groupName();
         var newopt = document.createElement("option");
         newopt.text = TranslateString(groupName);
         newopt.value = groupName;
         groupSelector.options.add(newopt);
      }
      if (oFilter.numGroups() > 1)
      {
         groupSelector.style.display = "";
      }
      else
      {
         groupSelector.style.display = "none";
      }
      groupSelector.selectedIndex = 0;
      this.updateGroup( groupSelector.selectedIndex );
   },

   onGroupChanged: function (e) {
      this.updateGroup(e.currentTarget.selectedIndex);
   },
   
   updateGroup: function(nSelectedIndex) {
      var oFilter = this.model.get('oFilter');
      oFilter.SelectGroup( nSelectedIndex );
      oFilter.SelectGroupValue( 0 );
      var listSelector = document.getElementById("TreeSortListSelect");
      listSelector.options.length = 0;
      if ( oFilter.numSortLists() > 0 )
      {
         for ( var lIndex = 0; lIndex < oFilter.numSortLists(); lIndex++ )
         {
            oFilter.SelectSortList( lIndex );
            var sortListName = oFilter.sortListName();
            var newopt = document.createElement("option");
            newopt.text = TranslateString(sortListName);
            newopt.value = sortListName;
            listSelector.options.add(newopt);
         }
         if (oFilter.numSortLists() > 1)
         {
            listSelector.style.display = "";
         }
         else
         {
            listSelector.style.display = "none";
         }
         listSelector.selectedIndex = 0;
         this.updateSortList( listSelector.selectedIndex );
      }
   },
   
   onSortListChanged: function(e) {
      this.updateSortList(e.currentTarget.selectedIndex);
   },
   
   updateSortList: function(nSelectedIndex) {
      var oFilter = this.model.get('oFilter');
      oFilter.SelectSortList(nSelectedIndex);
      this.drawDevices();
      //this.triggerResize();
   },

   resizeWidth: function() {
      // Set all items to have width of filterGroups
      var nWidth = this.$('.filterGroups').width();
      var nMinWidth = this.$('.ruler').width();
      if (nWidth < nMinWidth && nMinWidth > 0)
      {
         nWidth = nMinWidth;
      }
      this.$('.item').width(nWidth);
   },
   
   resizeHeight: function() {
      AVNav.prototype.resizeHeight.call(this);
      var nHeight = this.model.get('nHeight');
      var oHeaderDiv = this.$('.header');
      var oTreeBodyDiv = this.$('.treeBody');
      var nTreeBodyHeight = nHeight - oHeaderDiv.outerHeight(true);
      oTreeBodyDiv.height(nTreeBodyHeight);
      this.resizeWidth();
   }
   
});