var AVDeviceContainer = AVAction.extend({

   events: {
      "click .opFooter .buttons .ExecuteNoParam": "clickActionButton",//"clickButton",
      "click .opFooter .buttons .Execute": "clickActionButton",//"clickButton",
      "click #STR_VIEW_DETAILS": "clickDetails",
      "click .opFooter .buttons .Dismiss": "clickDismissButton",
      "change_combined .filterGroupSortLists": "onCombinedSelectionChange",
      "change_control .filterGroupSortLists": "onControlSelectionChange",
      "resize .controlInput": "resize"
   },

   refresh: function() 
   {
      this.render();
      this.resize();
      this.trigger("refreshCompleted");
   },

   render: function ()
   {
      AVAction.prototype.render.call(this);
      this.drawHeader();
      this.drawDeviceSelector();
      ClearDeviceSelection();
      this.drawFooter();
      this.updateButtons();
      return this;
   },

   clickActionButton: function(e) {
      $(e.currentTarget).blur();
      // Get action details.
      var sActionName = e.currentTarget.id;
      var oOpDetails = {
         'Name': sActionName,
         'bContainer': true // Indicates this operation details was created from a device container page.
      };
      
      // Display the action operation page in a popup.
      var oMConfigAction = new MConfigAction({
         'sDeviceID': this.model.get('sDeviceID'),
         'oOpDetails': oOpDetails,
         'bIsCombinedOp': true
      });
      var oVConfigAction = new VConfigAction({
         'model':oMConfigAction
      });
      
      this.$el.trigger("popup", {
         'sType': 'actionConfigPopup',
         'oVContent': oVConfigAction
      });

      oMConfigAction.bind("close_popup", this.onCombinedSelectionChange, this)
      oVConfigAction.onExecute(e, false);
      

      // TODO: Is this needed?
      //oVConfigAction.resize();

      return false;
   },

   clickDetails: function (e)
   {
      $(e.currentTarget).blur();
      var oDeviceIDs = this.oVControls[0].getValueArray();
      var sDeviceID = oDeviceIDs[0];
      var oMDetailsPopup = new MDetailsPopup({
         'sDeviceID': sDeviceID,
         'bIncludeStatusAlerts': this.model.get("bIncludeStatusAlerts")
      });
      var oVDetailsPopup = new VDetailsPopup({
         'model': oMDetailsPopup
      });
      this.$el.trigger("popup", {
         'sType': 'detailsPopup',
         'oVContent': oVDetailsPopup,
         'bClickOutsideToClose':true
      });
      return false;
   },

   // TODO: prevent redundant calls
   onCombinedSelectionChange: function (e)
   {
      // This is called when a popup is closed, and when there are 
      // no devices left (i.e. when using up all drives via create logical drive),
      // this.oVControls will be an empty array.
      if (IsDefined(this.oVControls) && this.oVControls.length > 0)
      {
         var oDeviceIDs = this.oVControls[0].getValueArray();
         var oParams = {};
         for (var i = 0; i < oDeviceIDs.length; ++i)
         {
            oParams["PV" + i] = oDeviceIDs[i];
         }
         if (oDeviceIDs.length > 0)
         {
            SelectDevices(oParams);
         }
         else
         {
            ClearDeviceSelection();
         }
         this.updateFooterInfo(this.oVControls[0]);
         this.updateButtons();
      }
   },

   updateButtons: function ()
   {
      var oButtons = GetCombineOperations(this.model.get('sType')).operations;
      var oButtonsDiv = this.$('.buttons').empty();
      // If only one device is selected, display the View Device Details button.
      var oDeviceIDs = [];
      if (IsDefined(this.oVControls[0]))
      {
         oDeviceIDs = this.oVControls[0].getValueArray();
      }
      if (oDeviceIDs.length == 1)
      {
         var sLabel = "STR_VIEW_DETAILS";
         var sClass = "button pianoButton combined Details";
         var oButtonDiv = $('<a/>', {
            'href': '',
            'id': sLabel,
            'class': sClass
         });
         oButtonDiv.html(TranslateString(sLabel));
         oButtonsDiv.append(oButtonDiv);
      }
      for (var j = 0; j < oButtons.length; ++j)
      {
         var oList = oButtons[j].OperationList;
         for (var i = 0; i < oList.length; ++i)
         {
            var sLabel = oList[i].Label;
            var sName = oList[i].Name;
            var sClass = "button pianoButton combined Execute";
            var oButtonDiv = $('<a/>', {
               'href': '',
               'id': sName,
               'class': sClass
            });
            oButtonDiv.html(TranslateString(sLabel));
            oButtonsDiv.append(oButtonDiv);
         }
      }
   },

   drawDeviceSelector: function ()
   {
      var oOpBodyDiv = this.$('.opBodyInner');
      var sType = this.model.get('sType');
      var sDeviceID = this.model.get("sDeviceID")
      var oChildren = EnumerateDevices(sType, sDeviceID);
      if (oChildren.devices.length > 0)
      {
         var oFilter = GetDeviceSortLists(sType, sDeviceID);
         var oMDeviceSelector = new MControlDeviceSelector(
         {
            'sType': 'combined',
            'sName': this.model.get('sName'),
            'oFilter': oFilter.filter,
            'bPopupTabbable': false,
            'oDevices': oChildren.devices
         });
         var oControlDiv = $('<div/>', { 'class': 'control' });
         var oVDeviceSelector = new VControlDeviceSelector({ 
            'id': 'DeviceSelector',
            'model': oMDeviceSelector
         });
         oControlDiv.append(oVDeviceSelector.$el);
         oOpBodyDiv.append(oControlDiv);
         this.oVControls.push(oVDeviceSelector);
      }
      else
      {
         this.drawEmptyNote();
      }
      return '';
   },

   drawEmptyNote: function ()
   {
      var oNotesDiv = this.$('.notes');
      var sClass = "NOTE";
      var sNote = this.model.get('sEmptyNote');
      
      var oMCollapsedNote = new MCollapsedNote({
         'nDisplay':"0",
         'oNotes':[{
            'NoteContent': [sNote],
            'NoteType': 'NOTE'
         }]
      });
      this.oVCollapsedNote = new VCollapsedNote({
         'model':oMCollapsedNote
      });
      oNotesDiv.append(this.oVCollapsedNote.$el);
   },

   clickDismissButton: function ()
   {
      // TODO: create views for new operation pages to be able to destroy them when switching tabs.
      this.render();
      TriggerResize();
      return false;
   }

});