var VArrayDiagnosticsReport = AVResize.extend({

   events: {
      "click .opFooter .buttons .CancelReport" : "clickCancelButton",
      "click .opFooter .buttons .Save" : "clickSaveButton",
      "click .opFooter .buttons .Dismiss" : "clickDismissButton"
   },

   initialize: function() {
      AVResize.prototype.initialize.call(this);
      this.model.on("change:oProgress", this.updateProgress, this);
      this.render();
   },

   dispose: function () {
      AVResize.prototype.dispose.call(this);
   },

   render: function() {
      var oDiv = this.$el;
      // Content header is used for page resizing.
      var oTriggerInput = $('<input/>', {
         'class': 'trigger',
         'type': 'hidden'
      });
      oDiv.append(oTriggerInput);
      
      // Draw widgets on dashboard.
      this.drawProgress(oDiv);
      return this;
   },

   drawBox: function(oParentDiv)
   {
      var oBoxWrapper = $('<div/>', {'class': 'boxWrapper'});
      var oBox = $('<div/>', {'class': 'box'});
      oBoxWrapper.append(oBox);
      oParentDiv.append(oBoxWrapper);
      return oBox;
   },

   drawProgress: function(oParentDiv) {
      var oProgressDiv = $('<div/>', {'class':'reportProgress'});
      var oTitle = $('<div/>', {'class': 'title'});
      oTitle.html(TranslateString("STR_DIAG_GUI_REPORT_PROGRESS"));
      oProgressDiv.append(oTitle);
      var oCurrentProgress = $('<div/>', {
         'class': 'progressDiv'
      });
      var oCurrentProgressLabel = $('<div/>', {
         'id':'currentProgressLabel',
         'class':'progressLabel'
      })
      oCurrentProgressLabel.html(TranslateString("STR_DIAG_GUI_CURRENT_PROGRESS"));
      var oCurrentProgressTable = this.getProgressBar("current");
      var oTotalProgress = $('<div/>', {
         'class': 'progressDiv'
      });
      var oTotalProgressLabel = $('<div/>', {
         'id':'totalProgressLabel',
         'class':'progressLabel'
      })
      oTotalProgressLabel.html(TranslateString("STR_DIAG_GUI_OVERALL_PROGRESS"));
      var oTotalProgressTable = this.getProgressBar("total");
      oCurrentProgress.append(oCurrentProgressLabel);
      oCurrentProgress.append(oCurrentProgressTable);
      oProgressDiv.append(oCurrentProgress);
      oTotalProgress.append(oTotalProgressLabel);
      oTotalProgress.append(oTotalProgressTable);
      oProgressDiv.append(oTotalProgress);
      oParentDiv.append(oProgressDiv);
   },

   getProgressBar: function(sProgressBarType) {
      var oProgressBar = $('<table/>', {
         'class':'progressBarTable'
      });
      var oProgressBarTR = $('<tr/>', {
         'class':'progressBarTR'
      });
      var oProgressBarDone = $('<td/>', {
         'id':sProgressBarType + 'Done',
         'class':'progressBarDoneTD',
         'width':'0%'
      });
      var oProgressBarNotDone = $('<td/>', {
         'id':sProgressBarType + 'NotDone',
         'class':'progressBarNotDoneTD',
         'width':'100%'
      });
      oProgressBarTR.append(oProgressBarDone);
      oProgressBarTR.append(oProgressBarNotDone);
      oProgressBar.append(oProgressBarTR);
      return oProgressBar;
   },

   drawSaveSSDReport: function() {
      // Indicate that report generation is finished
      // Get the report and display it
      this.drawHeader();
      var oBodyDiv = this.$('.opBodyInner');
      oBodyDiv.empty();
      var oReportDiv = $('<div/>', {'class':'reportDiv'});
      oBodyDiv.append(oReportDiv);
      oReportDiv.html(TranslateString("STR_SAVE_SSD_REPORT"));
      this.drawButtons();
   },

   drawSSDReport: function() {
      var oDiv = this.$el;
      oDiv.empty();
      var oReport = GetReportContentForDisplay("SSD");
      var oModel = new MWearGaugeTreeActions({
         'oReport': oReport.SmartSSDWearGaugeReport
      });
      this.oView = new VWearGaugeTreeActions({
         'model': oModel
      });
      oDiv.append(this.oView.$el);
   },

   updateProgress: function() {
      var sCurrentProgress = "";
      var o = this.model.get('oProgress');
      if (!o.isADUReportDone && !o.isADUReportCancelled)
      {
         if (o.numControllerDevicesTotal > 0)
         {
            var nPercentDone = Math.round(100.0 * o.numControllerDevicesProcessed / o.numControllerDevicesTotal, 1);
            if (nPercentDone > 100) {
               nPercentDone = 100;
            }
            else if (nPercentDone < 0) {
               nPercentDone = 0;
            }
            if (nPercentDone == 100) {
               sCurrentProgress = TranslateString("STR_DIAG_GUI_CURRENT_PROGRESS") + " > " + nPercentDone + "%";
            }
            else {
               sCurrentProgress = TranslateString("STR_DIAG_GUI_CURRENT_PROGRESS") + " > " + nPercentDone + "% > " + TranslateString("STR_DIAG_GUI_EXAMINING") + " " + o.currentDevice;
            }
            this.$('#currentProgressLabel').html(sCurrentProgress);
            this.$('#currentDone').css({
               'width':nPercentDone + "%"
            })
            this.$('#currentNotDone').css({
               'width':100 - nPercentDone + "%"
            })
            this.UpdateOverallProgress(2, o);
         }
         else
         {
            sCurrentProgress = TranslateString("STR_DIAG_GUI_CURRENT_PROGRESS") + " > " + TranslateString("STR_DIAG_GUI_SCANNING") + " " + o.currentTopLevelDevice + " > " + o.numDevicesTotal + " device" + (o.numDevicesTotal == 1 ? "" : "s") + " found";
            this.$('#currentProgressLabel').html(sCurrentProgress);
            this.UpdateOverallProgress(1, o);
         }
         if (o.numControllerDevicesTotal > 0)
         {
            this.UpdateOverallProgress(2,o);
         }
         else
         {
            this.UpdateOverallProgress(1,o);
         }
      }
      else if (!o.isADUReportCancelled)
      {
         this.UpdateOverallProgress(3,o);
      }
   },

   UpdateOverallProgress: function(stage, o)
   {
      var nPercentDone;
      var sOverallStatus = "";
      var nDeviceProgress;
      switch(stage)
      {
      case 1:
         sOverallStatus = TranslateString("STR_DIAG_GUI_SCANNING_SYSTEM");
         nPercentDone = 0;
         break;
      case 2:
         sOverallStatus = TranslateString("STR_DIAG_GUI_PROCESSING") + " " + o.currentTopLevelDevice;
         if (o.numDevicesTotal > 0)
         {
            nDeviceProgress = Math.round(95.0 * o.numDevicesProcessed / o.numDevicesTotal, 0);
         }
         else
         {
            nDeviceProgress = 95.0;
         }
         nPercentDone = nDeviceProgress;
         break;
      case 3:
         sOverallStatus = TranslateString("STR_DIAG_GUI_FORMATTING_REPORT");
         nPercentDone = 98;
         break;
      case 4:
         sOverallStatus = TranslateString("STR_DIAG_REPORT_PRESS_SAVE_REPORT");
         nPercentDone = 100;
         break;
      }
      if (stage == 4)
      {
         this.$('#currentProgressLabel').html(TranslateString("STR_DIAG_GUI_GENERATION_COMPLETE"));
         this.$('#currentDone').css({
            'width':"100%"
         })
         this.$('#currentNotDone').css({
            'width':"0%"
         })
         this.$('#totalProgressLabel').html(sOverallStatus);
      }
      else
      {
         var sTotalProgress = "";
         if (nPercentDone > 0)
         {
            sTotalProgress = TranslateString("STR_DIAG_GUI_OVERALL_PROGRESS") + " > " + nPercentDone + "% > " + sOverallStatus;
         }
         else
         {
            sTotalProgress = TranslateString("STR_DIAG_GUI_OVERALL_PROGRESS") + " > " + sOverallStatus;
         }
         this.$('#totalProgressLabel').html(sTotalProgress);
      }
      this.$('#totalDone').css({
         'width':nPercentDone + "%"
      })
      this.$('#totalNotDone').css({
         'width':100 - nPercentDone + "%"
      })
   },
   
   clickCancelButton: function() {
      CancelReport();
      window.history.back();
   },

   clickSaveButton: function() {
      var oReportDL = GetReportContentForDownload();
      document.location = "ADUReport.zip";
   },

   clickDismissButton: function() {
      window.history.back();
   }
});