var MHelpBuilder = AMResize.extend({

   defaults: {
      'sSelectedTitle': '',
      'oSelectedContent': ''
   },

   initialize: function() {
      AMResize.prototype.initialize.call(this);

      /* Help index template

			>>>> Template for new entry <<<<

			"TITLE":{
			   "isFolder":false,
			   "helpContent":{
			      "HEADER":{
			         "TYPE":[
			         "CONTENT"],
			         "TYPE":[
			         "CONTENT"]
			      },
			      "HEADER":{
			         "TYPE":[
			         "CONTENT"]
			      }
			   },
			   "inlineLink":{
			      "isDefinition":false,
			      "isCaseSensitive":true,
			      "exceptions":[
			      "EXCEPTION1",
			      "EXCEPTION2"]
			   }
			}

			+ TITLE is title/index of the entry
			   + isFolder indicates if it is a collapsable folder with entries underneath
			   + helpContent is the content
			      + HEADER is the string for the subheadings for each help entry
			      + TYPE is the type of content - they are:

			         - body: typical paragraph style content
			                 [
			                 "Item1",
			                 "Item2",
			                 "Item3"]

			         - note: a note for an entry ("Note:" will be appended to the front)
			                 structure is the same as body

			         - list: a bulleted list of items
			                 structure is the same as body

			         - task: a table of tasks, must be a JSON object with key-value pairs
			                 the key is the title of the task, the value is the description of the task
			                 [{
			                 "TASK1":"TASK1Description",
			                 "TASK2":"TASK2Description"}]

			         - table: creates a two column table
			                 [
			                 "TitleOfTable",
			                 {"HeaderForLeft":"HeaderForRight"},
			                 {"ITEM1":"ITEM1Description",
			                  "ITEM2":"ITEM2Description",
			                  "ITEM3":"ITEM3Description"}]

			      + CONTENT is the actual content with strings separated by commas, structured as above
			   + inlineLink contains the information for adding inline links for the entry
			      + isDefinition indicates if the inline link links to a definition in the glossary
			      + isCaseSensitive indicates if the inline link will be added with case-matching
			      + exceptions contains an array of strings that will not be matched for the entry
			*/

		var oHelp_Welcome = {
		   "isFolder":false,
		   "helpContent":{
		      "STR_OVERVIEW":{
		         "body":[
		         "HELP_OVERVIEW_SSA_WELCOME",
		         "HELP_OVERVIEW_SSA_PURPOSE"]
		      }
		   },
		   "inlineLink":{
		      "isDefinition":false,
		      "isCaseSensitive":false,
		      "exceptions":[]
		   }
		};

		var oHelp_GettingStarted = {
		   "isFolder":true,
		   "helpContent":{
		      "STR_GETTING_STARTED_WITH_SSA_OVERVIEW":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_SSA_OVERVIEW",
		               "HELP_SSA_OVERVIEW_2"]
		            },
		            "STR_HEADER":{
		               "body":[
		               "HELP_HEADER"]
		            },
		            "STR_LEFT_PANE":{
		               "body":[
		               "HELP_LEFT_PANE_OVERVIEW",
		               "HELP_LEFT_PANE_STATUS",
		               "HELP_LEFT_PANE_PROLIANT"]
		            },
		            "STR_RIGHT_PANE":{
		               "body":[
		               "HELP_RIGHT_PANE_OVERVIEW",
		               "HELP_RIGHT_PANE_OVERVIEW_ACTIONS"],
		               "list":[
		               "HELP_RIGHT_PANE_ACTION_LIST_1",
		               "HELP_RIGHT_PANE_ACTION_LIST_2"],
		               "body2":[
		               "HELP_RIGHT_PANE_STATUS",
		               "HELP_RIGHT_PANE_CONFIG_SUMMARY",
		               "HELP_MORE_HELP"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":false,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_IMAGE_LEGEND":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[],
		               "legend":[  // This is only drawn one way, so no need to
		               ]           // provide any additional information.
		            }              // See drawHelpImageLegend function.
		         },
		         "inlineLink":{
		            "isDefinition":false,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_KEYBOARD_SHORTCUTS":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_KEYBOARD_SHORTCUTS_OVERVIEW",
		               "HELP_KEYBOARD_SHORTCUTS_GLOBAL_OVERVIEW"],
		               "table":[
		               "HELP_KEYBOARD_SHORTCUTS_GLOBAL",
		               {"HELP_HOTKEYS_COL_KEY":"HELP_HOTKEYS_COL_DESC"},
		               {"HELP_KEYBOARD_CONTROLS_KEYS_TAB":"HELP_KEYBOARD_CONTROLS_KEYS_TAB_DESC",
		               "HELP_KEYBOARD_CONTROLS_KEYS_SHIFT_TAB":"HELP_KEYBOARD_CONTROLS_KEYS_SHIFT_TAB_DESC",
		               "F5":"STR_HOTKEY_F5",
		               "B":"STR_HOTKEY_B",
		               "H":"STR_HOTKEY_H",
		               "X":"STR_HOTKEY_X"}],
		               "body2":[
		               "HELP_KEYBOARD_SHORTCUTS_LOCAL_OVERVIEW"],
		               "table2":[
		               "HELP_KEYBOARD_SHORTCUTS_LOCAL",
		               {"HELP_HOTKEYS_COL_KEY":"HELP_HOTKEYS_COL_DESC"},
		               {"HELP_KEYBOARD_CONTROLS_KEYS_ENTER":"HELP_KEYBOARD_CONTROLS_KEYS_ENTER_DESC",
		               "HELP_KEYBOARD_CONTROLS_KEYS_ESCAPE":"HELP_KEYBOARD_CONTROLS_KEYS_ESCAPE_DESC",
		               "R":"STR_HOTKEY_R"}]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":false,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      }
		   }
		};

		var oHelp_Configure_HelpContent = {
		   "STR_CONFIGURE_OVERVIEW":{
		      "isFolder":false,
		      "helpContent":{
		         "STR_OVERVIEW":{
		            "body":[
		            "HELP_OVERVIEW_CONFIGURE_OVERVIEW"]
		         },
		         "STR_LEFT_PANE":{
		            "body":[
		            "HELP_LEFT_PANE_CONFIGURE"]
		         },
		         "STR_RIGHT_PANE":{
		            "body":[
		            "HELP_RIGHT_PANE_CONFIGURE"],
		            "list":[
		            "HELP_CONTROLLER_OVERVIEW",
		            "HELP_ARRAYS_OVERVIEW",
		            "HELP_UNASSIGNED_DRIVES_OVERVIEW",
		            "HELP_CACHE_MANAGER_OVERVIEW",
		            "HELP_LICENSE_MANAGER_OVERVIEW",
		            "HELP_ENCRYPTION_MANAGER_OVERVIEW"]
		         }
		      },
		      "inlineLink":{
		         "isDefinition":false,
		         "isCaseSensitive":false,
		         "exceptions":[]
		      }
		   },
		   "STR_CONTROLLER":{
		      "isFolder":true,
		      "helpContent":{
		         "HELP_CONTROLLER_OVERVIEW":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_RIGHT_PANE_CONTROLLER",
		                  "HELP_RIGHT_PANE_STATUS",
		                  "HELP_RIGHT_PANE_CONFIG_SUMMARY",
		                  "HELP_RIGHT_PANE_ACTIONS"],
		                  "note":[
		                  "HELP_ACTIONS_NOTE"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "STR_ACTIONS":{
		            "isFolder":true,
		            "helpContent":{
		               "OPERATION_WRITE_MANAGE_ADVANCED_CONTROLLER_PARAMETERS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"],
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS"]
		                     },
		                     "ATTR_NAME_PERFORMANCE_PROFILE":{
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS_PERFORMANCE_PROFILE"]
		                     },
		                     "ATTR_NAME_DEGRADED_PERFORMANCE_OPTIMIZATION":{
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS_DEGRADED_PERFORMANCE_OPTIMIZATION"]
		                     },
		                     "ATTR_NAME_ELEVATOR_SORT":{
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS_ELEVATOR_SORT"]
		                     },
		                     "ATTR_NAME_INCONSISTENCY_REPAIR_POLICY":{
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS_INCONSISTENCY_REPAIR_POLICY"]
		                     },
		                     "ATTR_NAME_QUEUE_DEPTH":{
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS_QUEUE_DEPTH"]
		                     },
		                     "ATTR_NAME_MNP_DELAY":{
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS_MNP_DELAY"]
		                     },
		                     "ATTR_NAME_FLEXIBLE_LATENCY_SCHEDULER_SETTING":{
		                        "body":[
		                        "HELP_TASK_ADVANCED_CONTROLLER_SETTINGS_FLS_SETTING"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_CLEAR_CONFIGURATION":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_CLEAR_CONFIGURATION"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_CLEAR_RIS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_CLEAR_RIS"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_CREATE_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_CREATE_ARRAY"],
		                        "note":[
		                        "HELP_NOTE_USE_SAME_DRIVE_SIZE",
		                        "HELP_NOTE_USE_SAME_DRIVE_TYPE"]
		                     }/*,
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "ATTR_NAME_INTERFACE":"HELP_TASK_CREATE_ARRAY_DRIVE_TYPE",
		                        "HELP_SEL_PD":"HELP_TASK_CREATE_ARRAY_SEL_PDS"}]
		                     }*/
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_DISABLE_OTHER_CONTROLLER":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_DISABLE_STANDBY_CONTROLLER"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_MANAGE_IDENTIFICATION_LEDS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OPERATION_WRITE_MANAGE_IDENTIFICATION_LEDS"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_MANAGE_CONTROLLER_PARAMETERS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_CONTROLLER_SETTINGS"]
		                     },
		                     "ATTR_NAME_EXPAND_PRIORITY":{
		                        "note":[
		                        "HELP_TASK_CONTROLLER_SETTINGS_EXPAND_PRIORITY_NOTE"],
		                        "task":[{
		                        "ATTR_VALUE_EXPAND_PRIORITY_HIGH":"HELP_TASK_CONTROLLER_SETTINGS_TRANSFORMATION_HIGH",
		                        "ATTR_VALUE_EXPAND_PRIORITY_MEDIUM":"HELP_TASK_CONTROLLER_SETTINGS_TRANSFORMATION_MEDIUM",
		                        "ATTR_VALUE_EXPAND_PRIORITY_LOW":"HELP_TASK_CONTROLLER_SETTINGS_TRANSFORMATION_LOW"}],
		                        "note2":[
		                        "HELP_TASK_CONTROLLER_SETTINGS_TRANSFORMATION_NOTE"]
		                     },
		                        "ATTR_NAME_REBUILD_PRIORITY":{
		                        "task":[{
		                        "ATTR_VALUE_REBUILD_PRIORITY_HIGH":"HELP_TASK_CONTROLLER_SETTINGS_REBUILD_HIGH",
		                        "ATTR_VALUE_REBUILD_PRIORITY_MEDIUM":"HELP_TASK_CONTROLLER_SETTINGS_REBUILD_MEDIUM",
		                        "ATTR_VALUE_REBUILD_PRIORITY_LOW":"HELP_TASK_CONTROLLER_SETTINGS_REBUILD_LOW"
		                        }],
		                        "note1":[
		                        "HELP_TASK_CONTROLLER_SETTINGS_REBUILD_NOTE"],
		                        "note2":[
		                        "HELP_TASK_CONTROLLER_SETTINGS_REBUILD_MED_HIGH_NOTE"]
		                     },
		                     "ATTR_NAME_SURFACE_ANALYSIS_DELAY":{
		                        "body":[
		                        "HELP_TASK_CONTROLLER_SETTINGS_SURFACE_ANALYSIS"],
		                        "task":[{
		                        "STR_DISABLED":"HELP_TASK_CONTROLLER_SETTINGS_SURFACE_DISABLED",
		                        "ATTR_VALUE_SURFACE_ANALYSIS_MODE_AGGRESSIVE_TRUE":"HELP_TASK_CONTROLLER_SETTINGS_SURFACE_HIGH",
		                        "ATTR_VALUE_SURFACE_ANALYSIS_MODE_AGGRESSIVE_FALSE":"HELP_TASK_CONTROLLER_SETTINGS_SURFACE_IDLE"
		                        }]
		                     },
		                     "ATTR_NAME_CURRENT_PARALLEL_SURFACE_SCAN_COUNT":{
		                        "body":[
		                        "HELP_TASK_CONTROLLER_SETTINGS_PARALLEL_SURFACE_SCAN_COUNT"],
		                     },
		                     "OPERATION_WRITE_SET_DRIVE_WRITE_CACHE":{
		                        "body":[
		                        "HELP_TASK_SET_DRIVE_WRITE_CACHE"],
		                        "note":[
		                        "STR_NOTE_DRIVE_WRITE_CACHE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_SET_SPARE_MODE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OPERATION_MODIFY_SPARE_MODE_DEFINITION"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_OP"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_SET_POWER_MODE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OPERATION_MODIFY_POWER_MODE_DEFINITION"],
		                        "note":[
		                        "STR_NOTE_SET_POWER_MODE_CHANGE_REBOOT"
		                        ]
		                     },
		                     "ATTR_NAME_POWER_MODE_CONFIGURED":{
		                        "task":[{
		                        "ATTR_VALUE_POWER_MODE_LOW":"HELP_TASK_POWER_MODE_LOW",
		                        "ATTR_VALUE_POWER_MODE_LOW_AUTOMATED":"HELP_TASK_POWER_MODE_LOW_AUTOMATED",
		                        "ATTR_VALUE_POWER_MODE_PERFORMANT":"HELP_TASK_POWER_MODE_PERFORMANT"}],
		                        "note":[
		                        "STR_NOTE_SET_POWER_MODE_CONFIG_CHANGE_REBOOT"
		                        ]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "GUI_OPERATION_REDUNDANCY_SETTINGS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_REDUNDANCY"]
		                     },
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "ATTR_NAME_ASYMMETRICAL_ACTIVE_ACTIVE_SUBMODE":"HELP_TASK_REDUNDANCY_MODE",
		                        "STR_PREFERRED_LD_PATHS":"HELP_TASK_REDUNDANCY_PATH"}]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_RECOVER_CACHE_MODULE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_RECOVER_CACHE_MODULE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_SET_BOOT_CONTROLLER":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_SET_BOOT_CONTROLLER"],
		                        "note":[
		                        "HELP_NOTE_OPERATION_PERFORMED_OFFLINE",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_OP",
		                        "HELP_NOTE_SOME_SERVERS_NOT_SUPPORT_OP"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "GUI_OP_WRITE_SET_BOOT_VOLUME":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_SET_BOOTABLE_VOLUME"],
		                     },
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "ATTR_NAME_BOOT_VOLUME_PRIMARY":"HELP_TASK_BOOT_VOLUME_PRIMARY",
		                        "ATTR_NAME_BOOT_VOLUME_SECONDARY":"HELP_TASK_BOOT_VOLUME_SECONDARY"}],
		                        "note":[
		                        "HELP_NOTE_OPERATION_PERFORMED_OFFLINE",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_OP"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_SET_SPLIT_READCACHE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_SET_SPLIT_READCACHE"],
		                        "note":[
		                        "STR_NOTE_READ_CACHE_MEMORY",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_OP",
		                        "HELP_NOTE_OPERATION_PERFORMED_OFFLINE",
		                        "STR_NOTE_REBOOT_REQUIRED"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }
		            }
		         },
		         "STR_HBA_MODE_FULL":{
		            "isFolder":true,
		            "helpContent":{
		               "HELP_HBA_MODE_OVERVIEW":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_HBA_MODE_OVERVIEW_CONTENT"],
		                        "note":[
		                        "HELP_GLOSSARY_SUPPORTED_CONTROLLERS_NOTE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "HELP_SMART_ARRAY_CONTROLLERS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_SMART_ARRAY_CONTROLLERS_HBA_CONTENT"],
		                        "table":[
		                        "STR_AVAILABLE_ACTIONS",
		                        {"ATTR_NAME_ACTION":"HELP_HOTKEYS_COL_DESC"},
		                        {"OPERATION_WRITE_ENABLE_HBA":"SA_OPERATION_WRITE_ENABLE_HBA_DESC",
		                        "OPERATION_WRITE_ENABLE_HBA_CANCEL":"SA_OPERATION_WRITE_ENABLE_HBA_CANCEL_DESC",
		                        "OPERATION_WRITE_ENABLE_SMARTARRAY":"SA_OPERATION_WRITE_ENABLE_SMARTARRAY_DESC",
		                        "OPERATION_WRITE_ENABLE_SMARTARRAY_CANCEL":"SA_OPERATION_WRITE_ENABLE_SMARTARRAY_CANCEL_DESC"}]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "HELP_SMART_HBA_CONTROLLERS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_SMART_HBA_CONTROLLERS_HBA_CONTENT"],
		                        "table":[
		                        "STR_AVAILABLE_ACTIONS",
		                        {"ATTR_NAME_ACTION":"HELP_HOTKEYS_COL_DESC"},
		                        {"OPERATION_WRITE_ENABLE_HBA":"SH_OPERATION_WRITE_ENABLE_HBA_DESC",
		                        "OPERATION_WRITE_ENABLE_HBA_CANCEL":"SH_OPERATION_WRITE_ENABLE_HBA_CANCEL_DESC",
		                        "OPERATION_WRITE_ENABLE_RAID":"SH_OPERATION_WRITE_ENABLE_RAID_DESC",
		                        "OPERATION_WRITE_ENABLE_RAID_CANCEL":"SH_OPERATION_WRITE_ENABLE_RAID_CANCEL_DESC"}]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }
		            }
		         }
		      }
		   },
		   "STR_ARRAYS":{
		      "isFolder":true,
		      "helpContent":{
		         "HELP_ARRAYS_OVERVIEW":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_ARRAYS_OVERVIEW_CONTENT",
		                  "HELP_ARRAYS_OVERVIEW_CONTENT_MIDDLE",
		                  "HELP_ARRAYS_OVERVIEW_CONTENT_RIGHT"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "OPERATION_WRITE_DEVICE_BLINK":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_BLINK_DEVICE"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "OPERATION_WRITE_CREATE_ARRAY":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_OVERVIEW_CREATE_ARRAY"],
		                  "note":[
		                  "HELP_NOTE_USE_SAME_DRIVE_SIZE",
		                  "HELP_NOTE_USE_SAME_DRIVE_TYPE"]
		               }/*,
		               "STR_TASK_OPTIONS":{
		                  "task":[{
		                  "ATTR_NAME_INTERFACE":"HELP_TASK_CREATE_ARRAY_DRIVE_TYPE",
		                  "HELP_SEL_PD":"HELP_TASK_CREATE_ARRAY_SEL_PDS"}]
		               }*/
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "STR_ARRAY":{
		            "isFolder":true,
		            "helpContent":{
		               "OPERATION_WRITE_REMOVE_ARRAY_GAPS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_REMOVE_ARRAY_GAPS"],
		                        "note":[
		                        "HELP_NOTE_REMOVE_ARRAY_GAPS"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_CREATE_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_CREATE_LD"],
		                        "note":[
		                        "HELP_NOTE_CREATE_LD",
		                        "HELP_NOTE_CREATE_LD_RPI"]
		                     },
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "ATTR_NAME_RAID":"HELP_TASK_LD_RAID",
		                        "ATTR_NAME_STRIPE_SIZE":"HELP_TASK_LD_SS",
		                        "ATTR_NAME_SECTORS":"HELP_TASK_CREATE_LD_SECTORS",
		                        "ATTR_NAME_USEABLE_BLOCKS":"HELP_TASK_CREATE_LD_SIZE",
		                        "ATTR_NAME_PARITY_INITIALIZATION_METHOD":"HELP_TASK_PARITY_METHOD",
		                 "ATTR_NAME_OVERPROVISIONING_OPTIMIZATION_ENABLED":"HELP_OVERPROVISIONING_OPTIMIZATION",
		                        "ATTR_NAME_ARRAY_ACCELERATOR":"HELP_TASK_CREATE_ARRAY_ACC"}]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_CREATE_SPLIT_MIRROR_BACKUP":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_CREATE_SPLIT_MIRROR_BACKUP"],
		                        "list":[
		                        "HELP_TASK_CREATE_SPLIT_MIRROR_BACKUP_CONDITION_RAID_1_0",
		                        "HELP_TASK_CREATE_SPLIT_MIRROR_BACKUP_CONDITION_RAID_1_ADM",
		                        "HELP_TASK_CREATE_SPLIT_MIRROR_BACKUP_CONDITION_RAID_10_ADM",
		                        "HELP_TASK_CREATE_SPLIT_MIRROR_BACKUP_CONDITION_RAID_0",
		                        "HELP_TASK_CREATE_SPLIT_MIRROR_BACKUP_CONDITION_BACKUP_HIDDEN"],
		                        "body2":[
		                        "HELP_TASK_CREATE_SPLIT_MIRROR_BACKUP_USAGE"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_DELETE_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_DELETE_ARRAY"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":true,
		                     "exceptions":[
		                     "OPERATION_WRITE_DELETE_ARRAY"]
		                  }
		               },
		               "OPERATION_WRITE_MANAGE_LOGICAL_DRIVE_ACCELERATION":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_WRITE_MANAGE_LOGICAL_DRIVE_ACCELERATION"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               /*"OPERATION_WRITE_EXPAND_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_EXPAND"],
		                        "note":[
		                        "HELP_NOTE_USE_SAME_DRIVE_SIZE"],
		                        "body2":[
		                        "HELP_EXPAND_OPTIONS"],
		                        "task":[{
		                        "ATTR_NAME_EXPAND_TYPE":"HELP_TASK_EXPAND_TYPE",
		                        "HELP_SEL_PD":"HELP_TASK_CREATE_ARRAY_SEL_PDS"}]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },*/
		               "OPERATION_WRITE_HEAL_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_HEAL_ARRAY"],
		                        "list":[
		                        "HELP_TASK_HEAL_ARRAY_CONDITION_ARRAY_TYPE",
		                        "HELP_TASK_HEAL_ARRAY_CONDITION_CAPACITY"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_MANAGE_DATA_DRIVES":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_WRITE_MANAGE_DATA_DRIVES"]
		                     },
		                     "OPERATION_WRITE_EXPAND_ARRAY":{
		                        "body":[
		                        "HELP_OVERVIEW_EXPAND"],
		                        "note":[
		                        "HELP_NOTE_USE_SAME_DRIVE_SIZE"],
		                        "body2":[
		                        "HELP_EXPAND_OPTIONS"],
		                        "task":[{
		                        "ATTR_NAME_EXPAND_TYPE":"HELP_TASK_EXPAND_TYPE",
		                        "HELP_SEL_PD":"HELP_TASK_CREATE_ARRAY_SEL_PDS"}]
		                     },
		                     "OPERATION_WRITE_MOVE_ARRAY":{
		                        "body":[
		                        "HELP_TASK_MOVE_ARRAY"],
		                        "list":[
		                        "HELP_TASK_MOVE_ARRAY_CONDITION_ELEMENTS",
		                        "HELP_TASK_MOVE_ARRAY_CONDITION_ARRAY_TYPE",
		                        "HELP_TASK_MOVE_ARRAY_CONDITION_CAPACITY"],
		                        "note":[
		                        "HELP_NOTE_MOVE_ARRAY"]
		                     },
		                     "OPERATION_WRITE_REPLACE_ARRAY":{
		                        "body":[
		                        "HELP_TASK_REPLACE_ARRAY"],
		                        "list":[
		                        "HELP_TASK_REPLACE_ARRAY_CONDITION_ELEMENTS",
		                        "HELP_TASK_REPLACE_ARRAY_CONDITION_STATUS",
		                        "HELP_TASK_REPLACE_ARRAY_CONDITION_CAPACITY"],
		                        "note":[
		                        "HELP_NOTE_REPLACE_ARRAY_TIME_CONSUMING"],
		                     },
		                     "OPERATION_WRITE_SHRINK_ARRAY":{
		                        "body":[
		                        "HELP_TASK_SHRINK_ARRAY"],
		                        "list":[
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_FREE_SPACE",
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_REMOVE_DRIVES",
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_RAID_1",
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_COMPOUND_RAID"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     },
		                     "OPERATION_WRITE_MIRROR_ARRAY":{
		                        "body":[
		                        "HELP_TASK_MIRROR_ARRAY"],
		                        "list":[
		                        "HELP_TASK_MIRROR_ARRAY_CONDITION_ALL_DRIVES_RAID0",
		                        "HELP_TASK_MIRROR_ARRAY_CONDITION_RESULTING_RAID_LEVEL"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_MANAGE_SPARE_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_SPARE_MGMT"],
		                        "note":[
		                        "HELP_NOTE_SPARE_MGMT",
		                        "HELP_NOTE_USE_SAME_DRIVE_SIZE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_MANAGE_SPLIT_MIRROR_BACKUP":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_MANAGE_SPLIT_MIRROR_BACKUP"],
		                        "list":[
		                        "HELP_TASK_MANAGE_SPLIT_MIRROR_BACKUP_CONDITION_REMIRROR_PRESERVE",
		                        "HELP_TASK_MANAGE_SPLIT_MIRROR_BACKUP_CONDITION_REMIRROR_ROLLBACK",
		                        "HELP_TASK_MANAGE_SPLIT_MIRROR_BACKUP_CONDITION_ACTIVATE_BACKUP"],
		                        "note":[
		                        "HELP_NOTE_PRIMARY_UNAVAILABLE",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               /*"OPERATION_WRITE_MOVE_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_MOVE_ARRAY"],
		                        "list":[
		                        "HELP_TASK_MOVE_ARRAY_CONDITION_ELEMENTS",
		                        "HELP_TASK_MOVE_ARRAY_CONDITION_ARRAY_TYPE",
		                        "HELP_TASK_MOVE_ARRAY_CONDITION_CAPACITY"],
		                        "note":[
		                        "HELP_NOTE_MOVE_ARRAY"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_REPLACE_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_REPLACE_ARRAY"],
		                        "list":[
		                        "HELP_TASK_REPLACE_ARRAY_CONDITION_ELEMENTS",
		                        "HELP_TASK_REPLACE_ARRAY_CONDITION_STATUS",
		                        "HELP_TASK_REPLACE_ARRAY_CONDITION_CAPACITY"],
		                        "note":[
		                        "HELP_NOTE_REPLACE_ARRAY_TIME_CONSUMING"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }, */
		               "OPERATION_WRITE_JOIN_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_RESYNC_MIRROR"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE",
		                        "HELP_NOTE_OPERATION_SPLIT_ARRAY_OFFLINE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               /*"OPERATION_WRITE_SHRINK_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_SHRINK_ARRAY"],
		                        "list":[
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_FREE_SPACE",
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_REMOVE_DRIVES",
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_RAID_1",
		                        "HELP_TASK_SHRINK_ARRAY_CONDITION_COMPOUND_RAID"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },*/
		               "OPERATION_WRITE_SPLIT_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_SPLIT_MIRROR"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE",
		                        "HELP_NOTE_OPERATION_SPLIT_ARRAY_OFFLINE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }
		            }
		         },
		         "STR_LOGICAL_DRIVES":{
		            "isFolder":true,
		            "helpContent":{
		               "OPERATION_WRITE_SET_ENCRYPTION_ENCODE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_ENCRYPTION_ENCODE_CONTENT"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_CREATE_CACHING_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_CREATE_CACHING_FOR_LOGICAL_DRIVE"]
		                     },
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "STR_RAID_AND_CACHE_WRITE_POLICY":"HELP_TASK_RAID_AND_CACHE_WRITE_POLICY",
		                        "ATTR_NAME_USEABLE_BLOCKS":"HELP_TASK_SMARTCACHE_SIZE"}],
		                        "note":[
		                        "STR_NOTE_MODIFY_SSD_CACHING_WRITEBACK",
		                        "STR_NOTE_MODIFY_SSD_CACHING_WRITEBACK_RAID_0",
		                        "STR_NOTE_MODIFY_SSD_CACHING_WRITEBACK_LICENSE",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_DELETE_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_DELETE_LOGICAL_DRIVE"],
		                        "note":[
		                        "STR_SELECT_ALL_REMOVE_LD_NOTE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":true,
		                     "exceptions":[
		                     "OPERATION_WRITE_DELETE_LOGICAL_DRIVE"]
		                  }
		               },
		               /*"OPERATION_WRITE_ERASE_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_ERASE_DRIVE"],
		                        "task":[{
		                        "HELP_TASK_ERASE_DRIVE_ONE_PASS":"HELP_TASK_ERASE_DRIVE_ONE_PASS_DESC",
		                        "HELP_TASK_ERASE_DRIVE_TWO_PASS":"HELP_TASK_ERASE_DRIVE_TWO_PASS_DESC",
		                        "HELP_TASK_ERASE_DRIVE_THREE_PASS":"HELP_TASK_ERASE_DRIVE_THREE_PASS_DESC"}],
		                        "body2":[
		                        "HELP_TASK_ERASE_DRIVE_DELETE_AFTER_ERASE"],
		                        "note":[
		                        "HELP_NOTE_REENABLE_PHYSICAL_DRIVE_AFTER_ERASE",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },*/
		               "OPERATION_WRITE_EXTEND_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_EXTEND"]
		                     },
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "ATTR_NAME_USEABLE_BLOCKS":"HELP_TASK_CREATE_LD_SIZE"}]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_MIGRATE_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_MIGRATE"]
		                     },
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "ATTR_NAME_PARITY_GROUP_COUNT":"HELP_TASK_PARITY_GROUP_COUNT",
		                        "ATTR_NAME_RAID":"HELP_TASK_LD_RAID",
		                        "ATTR_NAME_STRIPE_SIZE":"HELP_TASK_LD_SS"}]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_MOVE_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_MOVE_LD"],
		                        "list":[
		                        "HELP_TASK_MOVE_LD_CONDITION_ELEMENTS",
		                        "HELP_TASK_MOVE_LD_CONDITION_STATUS"],
		                        "note":[
		                        "HELP_NOTE_MOVE_LD_DELETE_ARRAY",
		                        "HELP_NOTE_MOVE_LD_TIME_CONSUMING"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_REENABLE_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_REENABLE_LOGICAL_DRIVE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_SET_ENCRYPTION_REKEY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_ENCRYPTION_REKEY_CONTENT"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_SET_ENCRYPTION_DRIVE_OPTIONS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_ENCRYPTION_VOLATILE_KEY_CONTENT"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_WRITE_SET_ENCRYPTION_VOLATILE_KEY_ACTION":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_ENCRYPTION_VOLATILE_KEY_ACTION_CONTENT"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }
		                //,
		               //"OPERATION_READ_SSD_CACHE_STATS":{
		               //   "isFolder":false,
		               //   "helpContent":{
		               //      "STR_OVERVIEW":{
		               //         "body":[
		               //         "HELP_OVERVIEW_READ_SSD_CACHE_STATS"],
		               //         "note":[
		               //         "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		               //      }
		               //   },
		               //   "inlineLink":{
		               //      "isDefinition":false,
		               //      "isCaseSensitive":false,
		               //      "exceptions":[]
		               //   }
		               //}
		            }
		         },
		         "STR_PHYSICAL_DRIVES":{
		            "isFolder":true,
		            "helpContent":{
		               "OPERATION_WRITE_ERASE_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_TASK_ERASE_DRIVE"],
		                        "task":[{
		                        "HELP_TASK_ERASE_DRIVE_ONE_PASS":"HELP_TASK_ERASE_DRIVE_ONE_PASS_DESC",
		                        "HELP_TASK_ERASE_DRIVE_TWO_PASS":"HELP_TASK_ERASE_DRIVE_TWO_PASS_DESC",
		                        "HELP_TASK_ERASE_DRIVE_THREE_PASS":"HELP_TASK_ERASE_DRIVE_THREE_PASS_DESC"}],
		                        /*"body2":[
		                        "HELP_TASK_ERASE_DRIVE_DELETE_AFTER_ERASE"],*/
		                        "note":[
		                        "HELP_NOTE_REENABLE_PHYSICAL_DRIVE_AFTER_ERASE",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }
		            }
		         }
		      }
		   },
		   "STR_UNASSIGNED_DRIVES":{
		      "isFolder":true,
		      "helpContent":{
		         "HELP_UNASSIGNED_DRIVES_OVERVIEW":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_UNASSIGNED_DRIVES"],
		                  "task":[{
		                  "HELP_UNASSIGNED_DRIVES_DRIVE_TYPE":"HELP_UNASSIGNED_DRIVES_DRIVE_TYPE_DESC",
		                  "HELP_UNASSIGNED_DRIVES_GROUP_BY":"HELP_UNASSIGNED_DRIVES_GROUP_BY_DESC",
		                  "HELP_UNASSIGNED_DRIVES_SORT_BY":"HELP_UNASSIGNED_DRIVES_SORT_BY_DESC"}],
		                  "body2":[
		                  "HELP_UNASSIGNED_DRIVES_ACTIONS"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         }
		      }
		   },
		   "STR_CACHE_MANAGER":{
		      "isFolder":true,
		      "helpContent":{
		         "HELP_CACHE_MANAGER_OVERVIEW":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_CACHE_MANAGER_OVERVIEW_CONTENT",
		                  "HELP_CACHE_MANAGER_OVERVIEW_CONTENT_2"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "OPERATION_WRITE_MANAGE_ARRAY_ACCELERATOR":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_TASK_CREATE_ARRAY_ACC"]
		               },
		               "ATTR_NAME_CACHE_RATIO":{
		                  "body":[
		                  "HELP_TASK_CONTROLLER_SETTINGS_CACHE_RATIO"]
		               },
		               "STR_OTHER_TASK_OPTIONS":{
		                  "task":[{
		                  "HELP_SEL_LD":"HELP_TASK_ARRAY_ACC",
		                  "ATTR_NAME_NO_BATTERY_WRITE_CACHE":"HELP_TASK_CREATE_ARRAY_ACC_WRITE_CACHING_DESC"}]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "OPERATION_WRITE_CREATE_CACHING_ARRAY":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "note":[
		                  "HELP_NOTE_CREATE_CACHING_ARRAY"],
		                  "body":[
		                  "HELP_OVERVIEW_CREATE_CACHING_ARRAY"]
		               },
		               "STR_TASK_OPTIONS":{
		                  "task":[{
		                  "ATTR_NAME_INTERFACE":"HELP_TASK_CREATE_SMARTCACHE_ARRAY_DRIVE_TYPE",
		                  "HELP_SEL_PD":"HELP_TASK_CREATE_SMARTCACHE_ARRAY_SEL_PDS"}],
		                  "note":[
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_1"],
		                  "list":[
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_2",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_3",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_4",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_5",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_6",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_7",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_8",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_9",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_10",
		                  "STR_WARNING_SMART_CACHE_DISABLED_FEATURES_11"],
		                  "note2":[
		                  "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "STR_SMART_CACHE_ARRAY":{
		            "isFolder":true,
		            "helpContent":{
		               "OPERATION_WRITE_CREATE_CACHING_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_CREATE_CACHING_FOR_LOGICAL_DRIVE"]
		                     },
		                     "STR_TASK_OPTIONS":{
		                        "task":[{
		                        "ATTR_NAME_PRIMARY_LUN_TO_CACHE":"HELP_TASK_PRIMARY_LUN_TO_CACHE",
		                        "STR_RAID_AND_CACHE_WRITE_POLICY":"HELP_TASK_RAID_AND_CACHE_WRITE_POLICY",
		                        "ATTR_NAME_USEABLE_BLOCKS":"HELP_TASK_SMARTCACHE_SIZE"}],
		                        "note":[
		                        "STR_NOTE_MODIFY_SSD_CACHING_WRITEBACK",
		                        "STR_NOTE_MODIFY_SSD_CACHING_WRITEBACK_RAID_0",
		                        "STR_NOTE_MODIFY_SSD_CACHING_WRITEBACK_LICENSE",
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                      }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "STR_OPERATION_WRITE_DELETE_CACHING_ARRAY":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_DELETE_CACHING_ARRAY"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }
		            }
		         },
		         "STR_SMART_CACHE_FOR_LD":{
		            "isFolder":true,
		            "helpContent":{
		               "HELP_OPERATION_WRITE_DELETE_CACHING_LOGICAL_DRIVE":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_DELETE_CACHING_LOGICAL_DRIVE"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               },
		               "OPERATION_READ_SSD_CACHE_STATS":{
		                  "isFolder":false,
		                  "helpContent":{
		                     "STR_OVERVIEW":{
		                        "body":[
		                        "HELP_OVERVIEW_READ_SSD_CACHE_STATS"],
		                        "note":[
		                        "HELP_NOTE_SOME_CONTROLLERS_NOT_SUPPORT_FEATURE"]
		                     }
		                  },
		                  "inlineLink":{
		                     "isDefinition":false,
		                     "isCaseSensitive":false,
		                     "exceptions":[]
		                  }
		               }
		            }
		         }
		      }
		   }
		};

		if (!isPersonality("H3C"))
		{
		   var oHelp_Configure_HelpContent_LicenseManager = {
		      "isFolder":true,
		      "helpContent":{
		         "HELP_LICENSE_MANAGER_OVERVIEW":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "note":[
		                  "HELP_NOTE_LICENSE_MANAGER"],
		                  "body":[
		                  "HELP_LICENSE_MANAGER_OVERVIEW_CONTENT",
		                  "HELP_LICENSE_MANAGER_OVERVIEW_CONTENT_2"],
		                  "table":[
		                  "HELP_LICENSE_KEY_STATUS_DEFINITIONS",
		                  {"ATTR_NAME_STATUS":"STR_DEFINITION"},
		                  {"ATTR_VALUE_STATUS_OK":"HELP_LICENSE_KEY_STATUS_OK",
		                  "ATTR_VALUE_STATUS_DUPLICATE_FEATURE_NAME":"HELP_LICENSE_KEY_STATUS_DUPLICATE_FEATURE_NAME",
		                  "ATTR_VALUE_STATUS_KEY_EXPIRED":"HELP_LICENSE_KEY_STATUS_KEY_EXPIRED",
		                  "ATTR_VALUE_STATUS_SERIAL_NUMBER_MISMATCH":"HELP_LICENSE_KEY_STATUS_SERIAL_NUMBER_MISMATCH",
		                  "ATTR_VALUE_STATUS_UNKNOWN_FEATURE_NAME":"HELP_LICENSE_KEY_STATUS_UNKNOWN_FEATURE_NAME"}]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "HELP_ADD_LICENSE_KEY":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_ADD_LICENSE_KEY_CONTENT"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "HELP_REMOVE_LICENSE_KEY":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_REMOVE_LICENSE_KEY_CONTENT"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         }
		      }
		   };
		   oHelp_Configure_HelpContent.STR_LICENSE_MANAGER = oHelp_Configure_HelpContent_LicenseManager;
		}

		if (isEncryptionSupported())
		{
		   var oHelp_Configure_HelpContent_EncryptionManager = {
		      "isFolder":true,
		      "helpContent":{
		         "HELP_ENCRYPTION_MANAGER_OVERVIEW":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_ENCRYPTION_MANAGER_OVERVIEW_CONTENT"],
		                  "table":[
		                    "HELP_ENCRYPTION_BASIC_OPERATIONS",
		                    {"STR_TASKS":"STR_DESCRIPTION"},
		                    {"OPERATION_WRITE_SET_ENCRYPTION_MODE":"HELP_ENCRYPTION_INITIAL_SETUP_CONTENT",
		                     "OPERATION_WRITE_SET_ENCRYPTION_LOGIN":"HELP_ENCRYPTION_LOGIN_CONTENT",
		                     "OPERATION_WRITE_SET_ENCRYPTION_LOGOUT":"HELP_ENCRYPTION_LOGOUT_CONTENT"}],
		                  "body2":[] // This is to add a space between the table and the next header
		               },
		               "HELP_ENCRYPTION_DASHBOARD_OVERVIEW":{
		                  "body":[
		                  "HELP_ENCRYPTION_DASHBOARD_OVERVIEW_CONTENT"]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":false,
		               "isCaseSensitive":false,
		               "exceptions":[]
		            }
		         },
		         "HELP_ENCRYPTION_SETTINGS":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_ENCRYPTION_SETTINGS_OVERVIEW_CONTENT"],
		                  "table":[
		                    "HELP_ENCRYPTION_SETTINGS",
		                    {"STR_SETTINGS":"STR_DESCRIPTION"},
		                    {"STR_ENCRYPTION":"HELP_ENCRYPTION_CONTENT",
		                     "ATTR_NAME_ENCRYPTION_STANDALONE_MODE_ENABLED":"HELP_ENCRYPTION_STANDALONE_MODE_ENABLED_CONTENT",
		                     "ATTR_NAME_KEK_NAME":"HELP_ENCRYPTION_KEK_NAME_CONTENT",
		                     "ATTR_NAME_ENCRYPTION_MIXED_VOLUMES_ENABLED":"HELP_ENCRYPTION_MIXED_VOLUMES_ENABLED_CONTENT",
		                     "STR_ENCRYPTION_BOOT_PASSWORD":"HELP_ENCRYPTION_BOOT_PASSWORD_CONTENT",
		                     "ATTR_NAME_ENCRYPTION_FW_LOCKED":"HELP_ENCRYPTION_FW_LOCKED_CONTENT",
		                     "ATTR_NAME_ENCRYPTION_CONTROLLER_LOCKED":"HELP_ENCRYPTION_CONTROLLER_LOCKED_CONTENT",
		                     "ATTR_NAME_ENCRYPTION_LOCAL_KEY_CACHE_ENABLED":"HELP_ENCRYPTION_LOCAL_KEY_CACHE_ENABLED_CONTENT",
		                     "ATTR_NAME_ENCRYPTION_PHYSICAL_DRIVE_COUNT":"HELP_ENCRYPTION_PHYSICAL_DRIVE_COUNT_CONTENT"}]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":true,
		               "isCaseSensitive":true,
		               "exceptions":[]
		            }
		         },
		         "HELP_ENCRYPTION_ACCOUNTS":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_ENCRYPTION_ACCOUNTS_OVERVIEW_CONTENT"],
		                  "table":[
		                    "HELP_ENCRYPTION_ACCOUNTS",
		                    {"STR_TASKS":"STR_DESCRIPTION"},
		                    {"STR_CRYPTO_PASSWORD":"HELP_ENCRYPTION_CRYPTO_PASSWORD_CONTENT",
		                     "ATTR_NAME_ENCRYPTION_RECOVERY_PARAMS_SET":"HELP_ENCRYPTION_RECOVERY_PARAMS_SET_CONTENT",
		                     "STR_USER_PASSWORD":"HELP_ENCRYPTION_USER_PASSWORD_CONTENT"}]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":true,
		               "isCaseSensitive":true,
		               "exceptions":[]
		            }
		         },
		         "HELP_ENCRYPTION_UTILITIES":{
		            "isFolder":false,
		            "helpContent":{
		               "STR_OVERVIEW":{
		                  "body":[
		                  "HELP_ENCRYPTION_UTILITIES_OVERVIEW_CONTENT"],
		                  "table":[
		                    "HELP_ENCRYPTION_UTILITIES",
		                    {"STR_TASKS":"STR_DESCRIPTION"},
		                    {"OPERATION_WRITE_SET_ENCRYPTION_RETURN_TO_FACTORY_MODE":"HELP_ENCRYPTION_RETURN_TO_FACTORY_MODE_CONTENT",
		                     "OPERATION_WRITE_SET_ENCRYPTION_FOREIGN_LOCAL_KEY_IMPORT":"HELP_ENCRYPTION_FOREIGN_LOCAL_KEY_IMPORT_CONTENT",
		                     "OPERATION_WRITE_SET_ENCRYPTION_RESCAN_KEYS":"HELP_ENCRYPTION_RESCAN_KEYS_CONTENT"}]
		               }
		            },
		            "inlineLink":{
		               "isDefinition":true,
		               "isCaseSensitive":true,
		               "exceptions":[]
		            }
		         }
		      }
		   };
		   oHelp_Configure_HelpContent.STR_ENCRYPTION_MANAGER = oHelp_Configure_HelpContent_EncryptionManager;
		}

		var oHelp_Configure = {
		   "isFolder":true,
		   "helpContent":oHelp_Configure_HelpContent
		};

		var oHelp_Diagnose = {
		   "isFolder":true,
		   "helpContent":{
		      "STR_DIAGNOSE_OVERVIEW":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_OVERVIEW_DIAGNOSTICS"],
		               "list":[
		               "STR_ACU_DIAGNOSTICS_OVERVIEW",
		               "STR_SMARTSSD_WEAR_GAUGE_OVERVIEW"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":false,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_ACU_DIAGNOSTICS":{
		         "isFolder":true,
		         "helpContent":{
		            "STR_ACU_DIAGNOSTICS_OVERVIEW":{
		               "isFolder":false,
		               "helpContent":{
		                  "STR_OVERVIEW":{
		                     "body":[
		                     "HELP_OVERVIEW_ACU_DIAGNOSTICS"]
		                  },
		                  "STR_TASKS":{
		                     "body":[
		                     "HELP_OVERVIEW_DIAGNOSTICS_TASKS"]
		                  }
		               },
		               "inlineLink":{
		                  "isDefinition":false,
		                  "isCaseSensitive":false,
		                  "exceptions":[]
		               }
		            }
		         }
		      },
		      "STR_SMARTSSD_WEAR_GAUGE":{
		         "isFolder":true,
		         "helpContent":{
		            "STR_SMARTSSD_WEAR_GAUGE_OVERVIEW":{
		               "isFolder":false,
		               "helpContent":{
		                  "STR_OVERVIEW":{
		                     "body":[
		                     "HELP_OVERVIEW_SMARTSSD_WEAR_GAUGE"]
		                  },
		                  "STR_TASKS":{
		                     "body":[
		                     "HELP_OVERVIEW_SMARTSSD_WEAR_GAUGE_TASKS"]
		                  }
		               },
		               "inlineLink":{
		                  "isDefinition":false,
		                  "isCaseSensitive":false,
		                  "exceptions":[]
		               }
		            },
		            "STR_SMARTSSD_DRIVE_INFORMATION":{
		               "isFolder":false,
		               "helpContent":{
		                  "STR_OVERVIEW":{
		                     "body":[
		                     "HELP_SSD_DRIVE_OVERVIEW"]
		                  },
		                  "STR_SSD_STATUS_MESSAGE":{
		                     "body":[
		                     "HELP_SSD_WEAR_STATUS"],
		                     "list":[
		                     "STR_OK",
		                     "ATTR_VALUE_STATUS_NOT_SUPPORTED",
		                     "STR_SMARTSSD_WEAR_GAUGE_LOG_FULL_WARNING",
		                     "STR_MSG_SSD_5PERCENT_LIFE_REMAINING",
		                     "STR_MSG_SSD_2PERCENT_LIFE_REMAINING",
		                     "STR_MSG_SSD_56DAY_WARNING",
		                     "STR_MSG_SSD_56_DAY_5PERCENT_LIFE_REMAINING",
		                     "STR_MSG_SSD_56_DAY_2PERCENT_LIFE_REMAINING",
		                     "STR_MSG_SSD_SMART_TRIP"]
		                  },
		                  "ATTR_NAME_EXINFO_POWER_ON_HOURS":{
		                     "body":[
		                     "HELP_SSD_POWER_ON_HOURS"]
		                  },
		                  "ATTR_NAME_EXINFO_SSD_REMAINING_DAYS_UNTIL_WEAROUT":{
		                     "body":[
		                     "HELP_SSD_REMAINING_DAYS_UNTIL_WEAROUT"]
		                  },
		                  "STR_LIFE_REMAINING":{
		                     "body":[
		                     "HELP_SSD_USAGE_REMAINING"]
		                  },
		                  "ATTR_NAME_EXINFO_SSD_UTILIZATION":{
		                     "body":[
		                     "HELP_SSD_UTILIZATION"]
		                  }
		               },
		               "inlineLink":{
		                  "isDefinition":false,
		                  "isCaseSensitive":false,
		                  "exceptions":[]
		               }
		            },
		            "STR_SMARTSSD_IMAGE_LEGEND":{
		               "isFolder":false,
		               "helpContent":{
		                  "STR_OVERVIEW":{
		                     "body":[
		                     "HELP_OVERVIEW_SMARTSSD_IMAGE_LEGEND"],
		                     "weargaugelegend":[ // This is only drawn one way, so no need to
		                     ]                   // provide any additional information.
		                  }                      // See drawItemBody function.
		               },
		               "inlineLink":{
		                  "isDefinition":false,
		                  "isCaseSensitive":false,
		                  "exceptions":[]
		               }
		            },
		            "STR_SSD_REPORT":{
		               "isFolder":false,
		               "helpContent":{
		                  "STR_OVERVIEW":{
		                     "body":[
		                     "STR_SSD_REPORT_OVERVIEW"]
		                  },
		                  "STR_SSD_SUMMARY":{
		                     "body":[
		                     "HELP_SSD_SUMMARY_TOTALS"],
		                     "list":[
		                     "STR_TOTAL_SMART_TRIP_SSD_WEAROUT",
		                     "STR_TOTAL_SMART_ARRAY_SSDS",
		                     "STR_TOTAL_NON_SMART_ARRAY_SSDS",
		                     "STR_TOTAL_SAS_SSDS",
		                     "STR_TOTAL_SATA_SSDS",
		                     "STR_TOTAL"],
		                     "body2":[
		                     "HELP_SSD_SUMMARY_LISTS"],
		                     "list2":[
		                     "STR_SSD_WITH_SMART_TRIP_WEAROUT",
		                     "STR_SSD_WITH_56DAY_WARNING",
		                     "STR_SSD_WITH_2PERCENT_WARNING",
		                     "STR_SSD_WITH_5PERCENT_WARNING"],
		                     "note":[
		                     "HELP_NOTE_EMPTY_TABLES_NOT_DISPLAYED"],
		                     "body3":[
		                     "HELP_SSD_STATUS_INFO"]
		                  },
		                  "STR_SMARTSSD_STATUS_ALERTS":{
		                     "body":[
		                     "HELP_SSD_STATUS_OVERVIEW"]
		                  },
		                  "STR_SMARTSSD_DRIVE_INFORMATION":{
		                     "body":[
		                     "HELP_SSD_DRIVE_INFO"]
		                  }
		               },
		               "inlineLink":{
		                  "isDefinition":false,
		                  "isCaseSensitive":false,
		                  "exceptions":[]
		               }
		            }
		         }
		      }
		   }
		};

		var oHelp_Glossary = {
		   "isFolder":true,
		   "helpContent":{
		      "HELP_GLOSSARY_ACTIVE_SPARE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ACTIVE_SPARE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_ADAPTER_ID":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ADAPTER_ID_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":true,
		            "exceptions":[]
		         }
		      },
		      "STR_ARRAY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ARRAYS_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[
		            "STR_ARRAY_CONTROLLER",
		            "HELP_GLOSSARY_ARRAY_CONFIGURATION_UTILITY",
		            "HELP_LINK_EXCEPTION_ARRAY_OF_INEXPENSIVE_DISKS",
		            "STR_ARRAY_SOLID",
		            "STR_ACU_DIAGNOSTICS",
		            "OPERATION_WRITE_MOVE_ARRAY",
		            "OPERATION_WRITE_EXPAND_ARRAY",
		            "OPERATION_WRITE_HEAL_ARRAY",
		            "OPERATION_WRITE_SHRINK_ARRAY",
		            "OPERATION_WRITE_REPLACE_ARRAY",
		            "STR_SMART_ARRAY"]
		         }
		      },
		      /*"HELP_GLOSSARY_ARRAY_CONFIGURATION_UTILITY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ARRAY_CONFIGURATION_UTILITY_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },*/
		      "STR_ROAMING_SPARE_DRIVE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "STR_ROAMING_SPARE_DRIVE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_IS_BOOT_CONTROLLER":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_BOOT_CONTROLLER_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_BOOTABLE_VOLUME":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_BOOTABLE_VOLUME_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_CACHE_HIT_RATE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_CACHE_HIT_RATE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_CACHE_HITS":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_CACHE_HITS_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_CACHE_MISSES":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_CACHE_MISSES_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_CACHE_WRITE_POLICY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_CACHE_WRITE_POLICY_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_ARRAY_ACCELERATOR":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ARRAY_ACCELERATOR_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_CAPACITY_EXPANSION":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_CAPACITY_EXPANSION_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_CONNECTION_NAME":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_CONNECTION_NAME_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_ENCRYPTION_MYROLE_CRYPTO":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_CRYPTO_OFFICER"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_DEDICATED_SPARE_DRIVE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "STR_DEDICATED_SPARE_DRIVE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_ENCRYPTION_SETUP_TYPES":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ENCRYPTION_SETUP_TYPES"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_ENCRYPTION_USER":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ENCRYPTION_USER"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_EXINFO_SSD_REMAINING_DAYS_UNTIL_WEAROUT":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_SSD_REMAINING_DAYS_UNTIL_WEAROUT"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_ENCRYPTION_EXPRESS_SETUP":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ENCRYPTION_EXPRESS_SETUP"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_SPARE_MODE_LEGACY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_FAILURE_SPARE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_FLEXIBLE_LATENCY_SCHEDULER":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_FLEXIBLE_LATENCY_SCHEDULER_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		       "STR_ENCRYPTION_FULL_SETUP":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ENCRYPTION_FULL_SETUP"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		     "HELP_GLOSSARY_GUID_PARTITION_TABLE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_GUID_PARTITION_TABLE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      /* "ATTR_NAME_HOST_MODE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_HOST_MODE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      }, */
		      "HELP_GLOSSARY_HBA_MODE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_HBA_MODE_DEFINITION"],
		               "note1":[
		               "HELP_GLOSSARY_HBA_MODE_NOTE"],
		               "note2":[
		               "HELP_GLOSSARY_SUPPORTED_CONTROLLERS_NOTE"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":true,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_HP_SSA_FULL":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_HP_SSA_FULL_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_HP_SMART_CACHE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "STR_HP_SMART_CACHE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_HP_SSA":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_HP_SSA_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":true,
		            "exceptions":[]
		         }
		      },
		      "STR_LOGICAL_DRIVE_ACCELERATOR_IO_BYPASS_SHORT":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_HP_SSD_SMART_PATH_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_LOCAL_KEY_CACHE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_LOCAL_KEY_CACHE"],
		           "note":[
		           "HELP_GLOSSARY_LOCAL_KEY_CACHE_NOTE"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_ENCRYPTION_STANDALONE_MODE_ENABLED_TRUE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_LOCAL_KEY_MANAGEMENT_MODE"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_LOGICAL_DRIVE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_LOGICAL_DRIVES_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[
		            "STR_LOGICAL_DRIVE_ACCELERATOR_IO_BYPASS_SHORT"]
		         }
		      },
		      "HELP_GLOSSARY_LOGICAL_DRIVE_EXTENSION":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_LOGICAL_DRIVE_EXTENSION_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_MASTER_BOOT_RECORD":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_MASTER_BOOT_RECORD_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_KEK_NAME":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_MASTER_KEY"],
		           "note":[
		           "HELP_GLOSSARY_MASTER_KEY_NOTE"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_MAXIMUM_BOOT_SIZE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_MAXIMUM_BOOT_SIZE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_QUEUE_DEPTH":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_QUEUE_DEPTH_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_MBR_PARTITION":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_MBR_PARTITION_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_MIGRATION":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_MIGRATION_DEFINTION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_NPG":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_NPG_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_ONLINE_RECOVERY_SERVER":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ONLINE_RECOVERY_SERVER_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_ONLINE_SPARE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_ONLINE_SPARE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_PARALLEL_SURFACE_SCAN":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_PARALLEL_SURFACE_SCAN_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_PARITY_GROUP":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_PARITY_GROUP_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_PARITY_INITIALIZATION":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_PARITY_INITIALIZATION_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_PLAINTEXT_VOLUME":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_PLAINTEXT_VOLUME"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_PHYSICAL_DRIVE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_PHYSICAL_DRIVES_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_ELEVATOR_SORT":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_PHYSICAL_DRIVE_REQUEST_ELEVATOR_SORT_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_PORT":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_PORT_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":true,
		            "exceptions":[
		            "HELP_LINK_EXCEPTION_SUPPORT",
		            "HELP_LINK_EXCEPTION_REPORT"]
		         }
		      },
		      "ATTR_NAME_EXINFO_POWER_ON_HOURS":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_SSD_POWER_ON_HOURS"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_BOOT_VOLUME_PRIMARY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_TASK_BOOT_VOLUME_PRIMARY"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_RAID_0":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_0_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_RAID_1":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_1_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[
		            "ATTR_VALUE_RAID_10",
		            "ATTR_VALUE_RAID_1ADM",
		            "ATTR_VALUE_RAID_10ADM"]
		         }
		      },
		      "ATTR_VALUE_RAID_10":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_10_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_RAID_1ADM":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_1ADM_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_RAID_10ADM":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_10ADM_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_RAID_5":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_5_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[
		            "ATTR_VALUE_RAID_50"]
		         }
		      },
		      "ATTR_VALUE_RAID_50":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_50_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_RAID_6":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_6_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[
		            "ATTR_VALUE_RAID_60"]
		         }
		      },
		      "ATTR_VALUE_RAID_60":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_60_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_DEGRADED_PERFORMANCE_OPTIMIZATION":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_5_6_50_60_DEGRADED_PERFORMANCE_OPTIMIZATION_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_INCONSISTENCY_REPAIR_POLICY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_INCONSISTENCY_RAID_6_60_REPAIR_POLICY_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_RAID_MODE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_MODE_DEFINITION"],
		               "note":[
		               "HELP_GLOSSARY_SUPPORTED_CONTROLLERS_NOTE"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":true,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_RAID_OVERHEAD":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_RAID_OVERHEAD_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_REBUILD_PRIORITY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_REBUILD_PRIORITY_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_REDUNDANT_CONTROLLERS":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_REDUNDANT_CONTROLLERS_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_ENCRYPTION_STANDALONE_MODE_ENABLED_FALSE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_REMOTE_KEY_MANAGEMENT_MODE"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_BUS_TYPE_SCSI":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_SCSI_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_SCSI_ID":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_SCSI_ID_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_BOOT_VOLUME_SECONDARY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_TASK_BOOT_VOLUME_SECONDARY"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_SMART_ARRAY_MODE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_SMART_ARRAY_MODE_DEFINITION"],
		               "note":[
		               "HELP_GLOSSARY_SUPPORTED_CONTROLLERS_NOTE"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":true,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_SMARTCACHE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_SMARTCACHE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		    "ATTR_NAME_OVERPROVISIONING_OPTIMIZATION_ENABLED":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_OVERPROVISIONING_OPTIMIZATION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_EXINFO_SSD_UTILIZATION":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_SSD_UTILIZATION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_STRIPE_SIZE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_STRIP_SIZE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "GUI_NAME_FULL_STRIPE_SIZE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_STRIPE_SIZE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_SURFACE_SCAN_ANALYSIS":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_SURFACE_SCAN_ANALYSIS_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_NAME_EXPAND_PRIORITY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_EXPAND_PRIORITY_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_TRANSIENT_DRIVE":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_TRANSIENT_DRIVE_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "HELP_GLOSSARY_USABLE_CAPACITY":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_USABLE_CAPACITY_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "STR_LIFE_REMAINING":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_SSD_USAGE_REMAINING"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_CACHE_WRITE_POLICY_WRITEBACK":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_WRITE_BACK_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      },
		      "ATTR_VALUE_CACHE_WRITE_POLICY_WRITETHROUGH":{
		         "isFolder":false,
		         "helpContent":{
		            "STR_OVERVIEW":{
		               "body":[
		               "HELP_GLOSSARY_WRITE_THROUGH_DEFINITION"]
		            }
		         },
		         "inlineLink":{
		            "isDefinition":true,
		            "isCaseSensitive":false,
		            "exceptions":[]
		         }
		      }
		   }
		};
		/*
		var oHelpIndex = {
		   "STR_MSG_WELCOME_TITLE":oHelp_Welcome,
		   "STR_GETTING_STARTED_WITH_SSA":oHelp_GettingStarted,
		   "STR_CONFIGURE":oHelp_Configure,
		   "STR_DIAGNOSE":oHelp_Diagnose,
		   "HELP_GLOSSARY":oHelp_Glossary
		};
		*/
		var oHelpIndex = {};
		oHelpIndex.STR_MSG_WELCOME_TITLE = oHelp_Welcome;
		oHelpIndex.STR_GETTING_STARTED_WITH_SSA = oHelp_GettingStarted;
		oHelpIndex.STR_CONFIGURE = oHelp_Configure;
		if (isDiagnosticsSupported())
		{
		   oHelpIndex.STR_DIAGNOSE = oHelp_Diagnose;
		}
		oHelpIndex.HELP_GLOSSARY = oHelp_Glossary;
		this.set({'oHelpIndex':oHelpIndex});
   }

})