var VHelpBuilder = AVResize.extend({

   events: {
      "click .helpItem" : "clickHelpItem",
      "click .inlineLink" : "clickInlineLink",
      "click .expandCollapseAllButton" : "clickExpandCollapseAll"
   },

   initialize: function() {
      var oThis = this;
      AVResize.prototype.initialize.call(oThis);
      var oNavBackwardButton = oThis.model.get('oNavBackwardButton');
      oNavBackwardButton.click(function() {
         return oThis.clickNavButton("backward");
      });
      var oNavForwardButton = oThis.model.get('oNavForwardButton');
      oNavForwardButton.click(function() {
         return oThis.clickNavButton("forward");
      });
      var oSearchBox = oThis.model.get('oSearchBox');
      oSearchBox.keyup(function() {
         oThis.searchKeyUp(oSearchBox);
      });
      oSearchBox.focus(function() {
         oThis.focusSearchBox(oSearchBox);
      });
      oSearchBox.blur(function() {
         oThis.resetSearchBox(oSearchBox);
      });
      var oClearSearchBox = oThis.model.get('oClearSearchBox');
      oClearSearchBox.click(function() {
         oThis.clearSearchBox();
      });
      oClearSearchBox.hide();

      oThis.oVHelpDisplay = null;
      oThis.oCHelpIndex = null;
      oThis.render();
   },

   render: function() {
      var oDiv = this.$el;

      // Create collection for the index
      this.oCHelpIndex = new CHelpIndex({
         'model':MHelpItem
      });

      // Create an object to store history
      this.oHistory = [];

      // Create an object to store inline link information
      this.oInlineLinks = [];
      
      // Add wrappers
      var oLeftWrapperDiv = $('<div/>', {'class':'helpLeftWrapper'});
      var oRightWrapperDiv = $('<div/>', {'class':'helpRightWrapper'});
      oDiv.append(oLeftWrapperDiv);
      oDiv.append(oRightWrapperDiv);

      // Initialize two columns (index/display)
      this.initializeIndex(oLeftWrapperDiv);
      this.initializeDisplay(oRightWrapperDiv);
      oDiv.append(GetClearFloatsDiv());

      return this;
   },

   initializeIndex: function(oDiv) {
      var oThis = this;
      oThis.model.bind("change:sSelectedTitle", oThis.updateDisplayModel, oThis);
      var oIndexHeaderDiv = $('<div/>', {'class':'helpIndexHeader'});
      var oIndexHeaderTitle = $('<div/>', {
         'class':'helpIndexHeaderTitle'
      });
      oIndexHeaderTitle.html(TranslateString("HELP_TOPICS"));
      var oExpandAllButton = $('<a/>', {
         'href':'',
         'class':'popupTabbable expandCollapseAllButton HPSSA_SPRITE icon',
         'id':'expandButton',
         'title':TranslateString("HELP_EXPAND_ALL")
      });
      var oCollapseAllButton = $('<a/>', {
         'href':'',
         'class':'popupTabbable expandCollapseAllButton HPSSA_SPRITE icon',
         'id':'collapseButton',
         'title':TranslateString("HELP_COLLAPSE_ALL")
      });
      oIndexHeaderDiv.append(oIndexHeaderTitle);
      oIndexHeaderDiv.append(oCollapseAllButton);
      oIndexHeaderDiv.append(oExpandAllButton);
      oDiv.append(oIndexHeaderDiv);

      var oIndexWrapperDiv = $('<div/>', {'class':'helpIndexWrapper'});
      var oIndexDiv = $('<div/>', {'class':'helpIndex'});
      var oIndexUL = $('<ul/>', {'class':'helpIndexUL'});
      oIndexWrapperDiv.append(oIndexDiv);
      oIndexDiv.append(oIndexUL);
      oDiv.append(oIndexWrapperDiv);
      oThis.createIndex(this.model.get('oHelpIndex'), oIndexUL, oThis);
   },

   initializeDisplay: function(oDiv) {
      var oMHelpDisplay = new MHelpDisplay({
         'sTitle': this.model.get('sSelectedTitle'),
         'oHelpContent': this.model.get('oSelectedContent'),
         'oInlineLinks': this.oInlineLinks
      });
      this.oVHelpDisplay = new VHelpDisplay({
         'model':oMHelpDisplay,
         'el':oDiv
      });
      this.folderToggle(false);
      var nSelectedIndex = this.model.get('nSelectedIndex');
      this.oHistory.push(nSelectedIndex);
      this.nHistoryPage = 0;
      this.expandIndexToID(this.model.get('nSelectedIndex'));
   },

   createIndex: function(obj, ul, oThis) {
      var oCHelpIndex = this.oCHelpIndex;
      var oInlineLinks = this.oInlineLinks;
      $.each(obj, function(key, val) {
         var bSelected = false;
         // Create help index item (both folders and non-folders)
         var helpIndexNumber = oCHelpIndex.size();
         // Set default selection
         if (key == oThis.model.get("sSelectedTitle"))
         {
            bSelected = true;
            oThis.model.set({
               'sSelectedTitle':key,
               'oSelectedContent':val.helpContent,
               'nSelectedIndex':helpIndexNumber
            });
         }
         var oMHelpItem = new MHelpItem({
            'sTitle':key,
            'isFolder':val.isFolder,
            'oHelpContent':val.helpContent,
            'isSelected':bSelected,
            'helpIndexNumber':helpIndexNumber
         });
         var oVHelpItem = new VHelpItem({
            'model':oMHelpItem,
            'el':ul
         });
         // Add the model to the help index collection to allow the display
         // to access help content associated with index items
         oCHelpIndex.add(oMHelpItem);
         // Add inlineLink information
         // Only add for non-folders
         if (!val.isFolder) {
            oInlineLinks.push({
               "sLinkName":key,
               "oLinkInfo":val.inlineLink,
               "helpIndexNumber":helpIndexNumber
            });
         }
         // If the helpItem is a folder, create a nested list underneath
         // for it's children and call createIndex on it's children
         if (val.isFolder) {
            var oNestedUL = $('<ul/>', {
               'class':'nestedUL'
            });
            var oNestedLI = $('<li/>', {
               'class':'nestedLI'
            });
            oNestedLI.append(oNestedUL);
            ul.append(oNestedLI);
            oThis.createIndex(val.helpContent, oNestedUL, oThis);
            oNestedUL.hide();
         }
      })
   },

   updateDisplayModel: function() {
      this.oVHelpDisplay.model.set({
         'sTitle': this.model.get("sSelectedTitle"),
         'oHelpContent': this.model.get("oSelectedContent")
      });
   },

   clickHelpItem: function(e) {
      var oCHelpIndex = this.oCHelpIndex;
      var oHelpItemHTML = this.$(e.currentTarget);
      var nIndexNumber = oHelpItemHTML.attr('id');
      var oHelpItem = oCHelpIndex.at(nIndexNumber);
      var oAttributes = oHelpItem.attributes;

      // If a help item was clicked (not a folder),
      //    - update the help display modle
      //    - update the selected item in the index
      if (!oAttributes.isFolder) {
         this.updateHistory(nIndexNumber);
         var sTitle = oAttributes.sTitle;
         this.model.set({
            'sSelectedTitle': sTitle,
            'oSelectedContent': oAttributes.oHelpContent,
            'nSelectedIndex': nIndexNumber
         })
         this.$('.selected').removeClass("selected");
         this.$('li a[id="' + nIndexNumber + '"]').addClass("selected");
      }
      // A folder was clicked, collapse/expand appropriately
      else {
         var oNextLI = oHelpItemHTML.parent("li").next("li");
         oNextLI.children(0).slideToggle('fast');
         var oIconDiv = oHelpItemHTML.find('.folderIcon');
         oIconDiv.toggleClass('closed');
         oIconDiv.toggleClass('open');
      }
      return false;
   },

   clickInlineLink: function(e) {
      var oCHelpIndex = this.oCHelpIndex;
      var oHelpItemHTML = this.$(e.currentTarget);
      var nIndexNumber = parseInt(oHelpItemHTML.attr('id'));
      var oHelpItem = oCHelpIndex.at(nIndexNumber);
      var oAttributes = oHelpItem.attributes;

      // If a help item was clicked (not a folder),
      //    - update the help display modle
      //    - update the selected item in the index
      if (!oAttributes.isFolder) {
         this.updateHistory(nIndexNumber);
         var sTitle = oAttributes.sTitle;
         this.model.set({
            'sSelectedTitle': sTitle,
            'oSelectedContent': oAttributes.oHelpContent,
            'nSelectedIndex': nIndexNumber
         });
         this.$('.selected').removeClass("selected");
         this.$('li a[id="' + nIndexNumber + '"]').addClass("selected");
         this.expandIndexToID(nIndexNumber);
      }
      // A folder was clicked, collapse/expand appropriately
      // This should never happen here
      else {
         var oNextLI = oHelpItemHTML.next();
         oNextLI.children(0).slideToggle('fast');
         var oIconDiv = oHelpItemHTML.find('.folderIcon');
         oIconDiv.toggleClass('closed');
         oIconDiv.toggleClass('open');
      }
      return false;
   },

   clickNavButton: function(sDirection) {
      var nHistoryPage = this.nHistoryPage;
      var bChangedPage = false;
      if (sDirection == "backward") {
         if (this.nHistoryPage < this.oHistory.length-1) {
            ++this.nHistoryPage;
            bChangedPage = true;
         }
      }
      else if (sDirection == "forward") {
         if (this.nHistoryPage > 0) {
            --this.nHistoryPage;
            bChangedPage = true;
         }
      }
      if (bChangedPage) {
         var oCHelpIndex = this.oCHelpIndex;
         var nIndexNumber = this.oHistory[this.nHistoryPage];
         var oHelpItem = oCHelpIndex.at(nIndexNumber);
         var oAttributes = oHelpItem.attributes;
         this.model.set({
            'sSelectedTitle':  oAttributes.sTitle,
            'oSelectedContent': oAttributes.oHelpContent,
            'nSelectedIndex': nIndexNumber
         });
         this.$('.selected').removeClass("selected");
         this.$('li a[id="' + nIndexNumber + '"]').addClass("selected");
         this.expandIndexToID(nIndexNumber);
      }
      this.updateNavButtons();
      return false;
   },

   updateHistory: function(nIndexNumber) {
      this.oHistory.splice(0, this.nHistoryPage);
      this.nHistoryPage = 0;
      this.oHistory.unshift(parseInt(nIndexNumber));
      this.updateNavButtons();
   },

   updateNavButtons: function() {
      var oNavBackwardButton = this.model.get('oNavBackwardButton');
      var oNavForwardButton = this.model.get('oNavForwardButton');
      var nHistoryPage = this.nHistoryPage;
      var oHistory = this.oHistory;
      if (oHistory.length == 1) {
         this.toggleNavButton(oNavBackwardButton, false)
         this.toggleNavButton(oNavForwardButton, false)
      }
      else {
         this.toggleNavButton(oNavBackwardButton, true)
         this.toggleNavButton(oNavForwardButton, true)
         if (nHistoryPage == 0) {
            this.toggleNavButton(oNavForwardButton, false)
         }
         else if (nHistoryPage == oHistory.length - 1) {
            this.toggleNavButton(oNavBackwardButton, false)
         }
      }
   },

   toggleNavButton: function(oNavButton, isEnabled) {
      if (isEnabled) {
         oNavButton.addClass('enabled');
         oNavButton.removeClass('disabled');
      }
      else {
         oNavButton.removeClass('enabled');
         oNavButton.addClass('disabled');
      }
   },

   searchKeyUp: function(oSearchBox) {
      var oCHelpIndex = this.oCHelpIndex;
      var sSearchString = '';
      if (IsDefined(oSearchBox)) {
         sSearchString = oSearchBox.val().toLowerCase();
      }
      var oHelpItems = this.$('.isNotFolder');
      for (var i=0; i<oHelpItems.length; ++i) {
         var nIndexNumber = $(oHelpItems[i]).attr('id');
         var oHelpItem = oCHelpIndex.at(nIndexNumber);
         var sTitle = TranslateString(oHelpItem.attributes.sTitle).toLowerCase();
         if (sTitle.indexOf(sSearchString) == -1) {
            $("#"+nIndexNumber).hide();
         }
         else {
            $("#"+nIndexNumber).show();
         }
      }
      this.hideShowFolders();
      // show clear search box button if search string is not blank
      var oClearSearchBox = this.model.get('oClearSearchBox');
      if (sSearchString != "") {
         //$("#clearButton").show();
         oClearSearchBox.show();
      }
      else {
         //$("#clearButton").hide();
         oClearSearchBox.hide();
      }
   },

   clearSearchBox: function() {
      var oSearchBox = this.model.get('oSearchBox');
      oSearchBox.val(TranslateString("HELP_SEARCH"));
      oSearchBox.addClass('empty');
      this.searchKeyUp();
   },

   resetSearchBox: function(oSearchBox) {
      if (oSearchBox.val() == "") {
         this.clearSearchBox();
      }
      this.model.get('oSearchBoxWrapper').removeClass('focused');
   },

   focusSearchBox: function(oSearchBox) {
      if (oSearchBox.val() == TranslateString("HELP_SEARCH")) {
         oSearchBox.val("");
      }
      oSearchBox.removeClass('empty');
      this.model.get('oSearchBoxWrapper').addClass('focused');
   },

   hideShowFolders: function() {
      var oFolders = this.$('.isFolder');
      for (var j=0; j<oFolders.length; ++j)
      {
         var oChildrenItems = $(oFolders[j]).parent("li").next("li.nestedLI").find('.isNotFolder');
         var bAllChildrenHidden = true;
         // Check if all children are hidden.
         for (var i=0; i<oChildrenItems.length && bAllChildrenHidden; ++i)
         {
            if ($(oChildrenItems[i]).css('display') != "none")
            {
               bAllChildrenHidden = false;
            }
         }
         // If all are hidden, hide the parent folder.
         if (bAllChildrenHidden)
         {
            $(oFolders[j]).hide();
         }
         // Otherwise make sure the parent folder is displayed.
         else
         {
            $(oFolders[j]).show();
         }
      }
   },

   clickExpandCollapseAll: function(e) {
      var expandCollapseAll = this.$(e.currentTarget).attr('id');
      if (expandCollapseAll == "expandButton") {
         this.folderToggle(true);
      }
      else if (expandCollapseAll == "collapseButton") {
         this.folderToggle(false);
      }
      return false;
   },

   folderToggle: function(bOpen) {
      // Toggle all folders as expanded or collapsed
      // true = expanded, false = collapsed
      if (bOpen) {
         this.$('.nestedUL').slideDown('fast');
         this.$('.folderIcon').removeClass('closed');
         this.$('.folderIcon').addClass('open');
      }
      else {
         $(".nestedUL").slideUp('fast');
         $(".folderIcon").removeClass('open');
         $(".folderIcon").addClass('closed');
      }
   },

   expandIndexToID: function(nIndexNumber) {
      var oSelectedIndex = this.$('li a[id="' + nIndexNumber + '"]');
      // Find all nestedUL's above the selected item
      var oParents = oSelectedIndex.parents('.nestedUL');
      // Expand all of them, change the icon for it's parent folder.
      for (var i=0; i<oParents.length; ++i) {
         var oParent = $(oParents[i]);
         oParent.slideDown(0);
         var oIconDiv = oParent.parent().prev().find('.folderIcon');
         oIconDiv.removeClass('closed');
         oIconDiv.addClass('open');
      }
      // Only scroll to the item if the item is not visible
      var oHelpIndexWrapper = this.$('.helpIndexWrapper');
      var nWrapperPosition = oHelpIndexWrapper.scrollTop();
      var nIndexPosition = oSelectedIndex.position().top;
      var nWrapperHeight = oHelpIndexWrapper.height();
      if (nIndexPosition > nWrapperHeight || nIndexPosition < 55) { // 55 is the height of the index + search header
         oHelpIndexWrapper.scrollTop(nWrapperPosition + oSelectedIndex.position().top - 200);
      }
   },

   resizeHeight: function() {
      AVResize.prototype.resizeHeight.call(this);
      var nHeaderHeight = this.$('.helpIndexHeader').outerHeight();
      var nIndexHeight = this.$('.helpLeftWrapper').height();
      var nHeight = nIndexHeight - nHeaderHeight;
      this.$('.helpIndexWrapper').height(nHeight);
   }

})