function GetStringMap()
{
   var o = GetData("strings/StringMap_.json");
   return o;
}

function GetData(sURL, oCallback, bAsync, oContext)
{
   var oResult = {};
   bAsync = IsDefined(bAsync) && bAsync;
   oCallback = IsDefined(oCallback) ? oCallback : function(o) {
      oResult = o;
   };
   // Include data in url rather than passing as jQuery data object to
   // prevent jQuery from escaping the ":" character found in device IDs.
   var o = {
      url: sURL,
      async: bAsync
   }
   if (IsDefined(oContext))
   {
      o.context = oContext;
   }

   // Check the status of the response
   var sResponseText = $.ajax(o)
      .always(function(oReturnData, sTextStatus, ojqXHR) {
         // This part is to handle the smh timeout from linux.
         if(typeof(oReturnData) == "string" && oReturnData.indexOf('content="System Management Homepage"') != -1) {
            alert(TranslateString("STR_LINUX_SMH_TIMEOUT_MESSAGE"));
            window.close();
         }
      })
      .done(oCallback);

   if (sURL == "GetReportContentForDisplay.json?PV0=HTML")
   {
      oResult = sResponseText.responseText;
   }
   return oResult;
}

function PostData(sURL, sData, oCallback, bAsync, oContext)
{
   var oResult = {};
   bAsync = IsDefined(bAsync) && bAsync;
   oCallback = IsDefined(oCallback) ? oCallback : function(o) {
      oResult = o;
   };
   var o = {
      url: sURL,
      async: bAsync,
      type: 'POST',
      data: sData
   }
   if (IsDefined(oContext))
   {
      o.context = oContext;
   }
   var sResponseText = $.ajax(o).done(oCallback);
   if (sURL == "GetReportContentForDisplay.json?PV0=HTML")
   {
      oResult = sResponseText.responseText;
   }
   return oResult;
}

function GetStringMaps()
{
   var o = GetData("strings/StringMaps.json");
   return o;
}

function GetIconMap()
{
   var o = GetData("strings/IconMap.json");
   return o;
}

function ClearDeviceSelection()
{
   return GetData("ClearDeviceSelection.json");
}

function ClearMasterDeviceSelection()
{
   return GetData("ClearMasterDeviceSelection.json");
}

// bFetch - True or false to bypass browser cache and fetch data from server.
// If reading from cache, will not select the device.
function GetDeviceIDSection( sID, bFetch )
{
   bFetch = IsDefined(bFetch) ? bFetch : false;
   // Access cached data.
   var oDeviceDetails = g_oDeviceDetails[sID];
   if (!IsDefined(oDeviceDetails) || bFetch)
   {
      oDeviceDetails = GetDeviceDetails(sID, 0, null, null, null, bFetch);
      //oDeviceDetails = g_oDeviceDetails[sID];
   }
   else
   {
      oDeviceDetails = oDeviceDetails.oDetails;
   }
   return oDeviceDetails.device[0];
}

// TODO: Optimize this.
function ClearAll()
{
   g_oDeviceDetails = [];
   g_oEnumerateDevices = [];
   g_oEnumerateDevicesID = [];
   g_oDeviceSortLists = [];
   g_oEnumerateOperations = [];
}

// Beware of clearing device details too slowly. Navigation may be refreshed before devices are cleared via async callback function call.
function ClearDeviceDetails(sType)
{
   // Clear Device Details
   for (sID in g_oDeviceDetails)
   {
      if (!IsDefined(g_oDeviceDetails[sID].oDetails.device[0]))
      {
         //(sType, sID, g_oDeviceDetails[sID]);
      }
      else
      {
         var sDeviceType = g_oDeviceDetails[sID].oDetails.device[0].DEVICE_TYPE;
         /*
         var sInvDeviceTypes;
         if (sType == "TypeAssignedDrive" || sType == "TypeUnassignedDrive")
         {
            sInvDeviceTypes = "ATTR_VALUE_TYPE_PHYSICAL_DRIVE";
         }
         else if (sType == "TypeLogicalDrive")
         {
            sInvDeviceTypes = "ATTR_VALUE_TYPE_LOGICAL_DRIVE";
         }
         else if (sType == "TypeLogicalArray")
         {
            sInvDeviceTypes = "ATTR_VALUE_TYPE_ARRAY";
         }
         else if (sType == "TypeSmartArrayController")
         {
            sInvDeviceTypes = "ATTR_VALUE_TYPE_ARRAY_CONTROLLER";
         }*/
         if (sDeviceType == sType)
         {
            delete(g_oDeviceDetails[sID]);
         }
      }
   }

   // Clear Enumerated Devices
   if (IsDefined(g_oEnumerateDevices[sType]))
   {
      delete(g_oEnumerateDevices[sType]);
   }
   if (IsDefined(g_oEnumerateDevicesID[sType]))
   {
      for (sID in g_oEnumerateDevicesID[sType])
      {
         delete(g_oEnumerateDevicesID[sType][sID]);
      }
      delete(g_oEnumerateDevicesID[sType]);
   }

   // Clear Device Sort Lists
   if (IsDefined(g_oDeviceSortLists[sType]))
   {
      for (sID in g_oDeviceSortLists[sType])
      {
         delete(g_oDeviceSortLists[sType][sID]);
      }
      delete(g_oDeviceSortLists[sType]);
   }

   // Clear Enumerated Device Operations
   if (IsDefined(g_oEnumerateOperations[sType]))
   {
      for (sID in g_oEnumerateOperations[sType])
      {
         delete(g_oEnumerateOperations[sType][sID]);
      }
      delete(g_oEnumerateOperations[sType]);
   }
}

function GetDeviceType(sID)
{
   var oDevice = GetDeviceIDSection(sID);
   return oDevice.DEVICE_TYPE;
}

// Called when selecting root device. Clears controller selection.
function SelectBaseDevice()
{
   return GetData("SelectBaseDevice.json");
}

// bSelectDevice - if true, selects the device when getting details from cache.
function GetDeviceDetails(sID, sLvl, oCallback, bAsync, oContext, bFetch, bSelectDevice)
{
   if (!IsDefined(sID))
   {
      //(sID, sLvl, oCallback, bAsync, oContext, bFetch);
   }
   if (!IsDefined(sLvl))
   {
      sLvl = 3;
   }
   if (!IsDefined(bSelectDevice))
   {
      bSelectDevice = true;
   }
   bFetch = IsDefined(bFetch) ? bFetch : false;
   var oResult;
   var oCachedDeviceDetails = g_oDeviceDetails[sID];
   var bCallbackContext = IsDefined(oCallback) && IsDefined(oContext);
   // If cache hit, use it. Make sure the level of device details requested is less than
   // or equal to the cached detail level.
   if (!bFetch && IsDefined(oCachedDeviceDetails) && oCachedDeviceDetails.sLvl >= sLvl)
   {
      if (bSelectDevice)
      {
         SelectDevice(sID);
      }
      // If callback function is supplied, execute it.
      if (bCallbackContext)
      {
         // Execute the callback function within the supplied context.
         oResult = oCallback.call(oContext, oCachedDeviceDetails.oDetails);
      }
      else
      {
         oResult = oCachedDeviceDetails.oDetails;
      }
   }
   else
   {
      // TODO: make sure that GetData helps to cache the retrieved device details.
      var oCB;
      // If callback function is supplied, wrap it in a function that will help
      // cache the response.
      if (bCallbackContext)
      {
         oCB = function(o) {
            g_oDeviceDetails[sID] = {
               'sLvl' : sLvl,
               'oDetails' : o
            };
            // Execute the callback function within the supplied context.
            return oCallback.call(oContext, o);
         };
      }
      oResult = GetData("GetDeviceDetails.json?PROP=device&PV0=" + encodeURIComponent(sID) + "&PV1=" + sLvl, oCB, bAsync, this);
      // If no callback was supplied, cache the response here.
      if (!bCallbackContext)
      {
         g_oDeviceDetails[sID] = {
               'sLvl' : sLvl,
               'oDetails' : oResult
            };
      }
   }
   return oResult;
}

// Returns summary details for a group of devices.
// Displayed in footers (e.g. # devices selected).
function GetDevicesDetails(oParams)
{
   var sParams = "PROP=d&" + $.param(oParams);
   return PostData("GetDeviceDetails.json", sParams);
}

/*function GetControllerActivities()
{
   return GetData("GetControllerActivities.json");
}
*/
function ExitApplication()
{
   return GetData("ExitApplication.json");
}

function GetVariables(s)
{
   return GetData("GetVariables.json");
}

// bFetch default to false
function EnumerateDevices(sDeviceType, sID, bFetch)
{
   var o;
   var bFetch = IsDefined(bFetch) ? bFetch : false;
   if (!bFetch)
   {
      if (IsDefinedAndSet(sID) && IsDefinedAndSet(g_oEnumerateDevicesID[sDeviceType]))
      {
         o = g_oEnumerateDevicesID[sDeviceType][sID];
      }
      else
      {
         o = g_oEnumerateDevices[sDeviceType];
      }
   }
   if (!IsDefinedAndSet(o))
   {
      var s = "EnumerateDevices.json?PROP=devices&PV0=" + sDeviceType;
      if (IsDefined(sID))
      {
         s += "&PV1=" + encodeURIComponent(sID);
         if (!IsDefinedAndSet(g_oEnumerateDevicesID[sDeviceType]))
         {
            g_oEnumerateDevicesID[sDeviceType] = {};
         }
         o = g_oEnumerateDevicesID[sDeviceType][sID] = GetData(s);
      }
      else
      {
         o = g_oEnumerateDevices[sDeviceType] = GetData(s);
      }
   }
   return o;
}

function GetOperations(sDeviceType, sID, bFetch)
{
   var o;
   //var bFetch = IsDefined(bFetch) ? bFetch : false;
   var bFetch = true;
   if (!bFetch && IsDefinedAndSet(g_oEnumerateOperations[sDeviceType]))
   {
      o = g_oEnumerateOperations[sDeviceType][sID];
   }
   if (!IsDefinedAndSet(o))
   {
      if (!IsDefinedAndSet(g_oEnumerateOperations[sDeviceType]))
      {
         g_oEnumerateOperations[sDeviceType] = {};
      }
      o = g_oEnumerateOperations[sDeviceType][sID] = GetData("EnumerateOperations.json?PROP=operations&PV0=" + sDeviceType + "&PV1=" + encodeURIComponent(sID));
   }
   return o;
}

function GetOperationDetails(sOperation,sDeviceID)
{
   var requestString = "GetOperationDetails.json?PROP=operationDetails&PV0=" + sOperation;
   if ( typeof(sDeviceID) != "undefined" )
   {
      requestString += "&PV1=" + encodeURIComponent(sDeviceID);
   }
   return GetData(requestString);
}

// oOpParams should include operation controls and operation button.
function ExecuteOperation(oParams, oCallback, bAsync, oContext)
{
   var sParams = "PROP=operationDetails&" + $.param(oParams);
   return PostData("ExecuteOperation.json", sParams, oCallback, bAsync, oContext);
}
function ExecuteCombineOperation(oParams, oCallback, bAsync, oContext)
{
   var sParams = "PROP=operationDetails&" + $.param(oParams);
   return PostData("ExecuteCombineOperation.json", sParams, oCallback, bAsync, oContext);
}

function CancelOperation()
{
   return GetData("CancelOperation.json");
}

function GetDeviceSortLists(sDeviceType, sID, bFetch)
{
   var o;
   var bFetch = IsDefined(bFetch) ? bFetch : false;
   if (!bFetch && IsDefinedAndSet(g_oDeviceSortLists[sDeviceType]))
   {
      o = g_oDeviceSortLists[sDeviceType][sID];
   }
   if (!IsDefinedAndSet(o))
   {
      if (!IsDefinedAndSet(g_oDeviceSortLists[sDeviceType]))
      {
         g_oDeviceSortLists[sDeviceType] = {};
      }
      o = g_oDeviceSortLists[sDeviceType][sID] = GetData("GetDeviceSortLists.json?PROP=filter&PV0=" + sDeviceType + "&PV1=" + encodeURIComponent(sID));
   }
   return o;
}

function SelectDevice(deviceID)
{
   return GetData("SelectDevice.json?PROP=d&PV0=" + encodeURIComponent(deviceID));
}

function SelectDevices(oParams)
{
   var sParams = $.param(oParams);
   return GetData("SelectDevice.json?PROP=d&" + sParams);
}

function BeginMultiDeviceSelection()
{
   return GetData("BeginMultiDeviceSelection.json?PV0=1");
}

function GetCombineOperations(sDeviceType)
{
   return GetData("EnumerateCombineOperations.json?PROP=operations&PV0=" + sDeviceType);
}

// Report---------------
/*function GetReportContentForDisplay(oCallback, bAsync, oContext)
{
   return GetData("GetReportContentForDisplay.json?PV0=HTML", oCallback, bAsync, oContext);
}*/
function GetReportContentForDisplay(sReportType)
{
   return GetData("GetReportContentForDisplay.json?PV0=" + sReportType);
}

function GetReportContentForDownload()
{
   return GetData("ADUReport.json");
}

// sReportType - "SSD" or "ADU"
function BeginReport(sReportType, deviceID, oCallback, bAsync, oContext)
{
   return GetData("Begin" + sReportType + "Report.json?PROP=d&PV0=" + encodeURIComponent(deviceID), oCallback, bAsync, oContext);
}

function GetReportGenerationStatus(oCallback, bAsync, oContext)
{
   return GetData("GetReportGenerationStatus.json", oCallback, bAsync, oContext);
}

function CancelReport()
{
   return GetData("CancelReportGeneration.json");
}

function GetErrorReport(sDeviceID)
{
   return GetData("GetErrorReport.json?PV0=" + sDeviceID);
}

function EnumerateRemovableDevices(oCallBack)
{
   return GetData("EnumerateRemovableDevices.json", oCallBack);
}

function WriteReportToRemovableDevice(sSelectedDrive, sFilename, oCallback)
{
   return GetData("WriteReportToRemovableDevice.json?PV0=" + sSelectedDrive + "&PV1=" + sFilename, oCallback);
}

function EnumerateAllowedDeviceTasks(sDeviceID)
{
   return GetData("EnumerateAllowedDeviceTasks.json?PV0=" + encodeURIComponent(sDeviceID));
}

function RefreshDeviceDetails(sDeviceID, sLvl)
{
   return GetData("RefreshDeviceDetails.json?PV0=" + encodeURIComponent(sDeviceID) + "&PV1=" + sLvl);
}

function GetEncryptionDashboard()
{
   return GetData("GetEncryptionDashboard.json?");
}

// Search controllers for warnings we want to report on a global level.
function UpdateGlobalAlerts(sCtrlID)
{
   // Warnings we want to report on a global level. Currently we only care about volatile keys.
   var sVolatileKeyCode = "958";

   // Get controllers.
   var oControllerList = g_oMSSA.get('oControllerList');
   var sCtrlVolatileList = '';
   var sControllerLabel = false;

   // If no specific controller ID was specified, update all controllers.
   if (!IsDefined(sCtrlID))
   {
      g_oVolatileKeyControllers = [];
      for (var i=0; i<oControllerList.length; ++i)
      {
         sControllerLabel = HasStatus(oControllerList[i], sVolatileKeyCode);
         if (sControllerLabel != false)
         {
            g_oVolatileKeyControllers.push(sControllerLabel);
         }
      }
   }
   // Otherwise, just update the specified controller: sCtrlID.
   else
   {
      sControllerLabel = HasStatus(sCtrlID, sVolatileKeyCode);
      var sLabel;
      // Get the current controller label.
      if (sControllerLabel == false)
      {
         var oDevice = GetDeviceDetails(sCtrlID, 1, null, null, null, false, false).device;
         sLabel = oDevice[0].LABEL;
      }
      else
      {
         sLabel = sControllerLabel;
      }
      var nIndexFound = -1;
      for (var j=0; (nIndexFound == -1) && j<g_oVolatileKeyControllers.length; ++j)
      {
         if (g_oVolatileKeyControllers[j] == sLabel)
         {
            nIndexFound = j;
         }
      }
      // If controller has the status, then add it to the global list.
      if (sControllerLabel)
      {
         // If controller was not found in the global list, add it.
         if (nIndexFound == -1)
         {
            g_oVolatileKeyControllers.push(sControllerLabel);
         }
      }
      // Otherwise, make sure it is not in the global list.
      else
      {
         if (nIndexFound != -1)
         {
            g_oVolatileKeyControllers.splice(nIndexFound, 1);
         }
      }
   }
   for (var k=0; k<g_oVolatileKeyControllers.length; ++k)
   {
      if (sCtrlVolatileList != '')
      {
         sCtrlVolatileList += ", ";
      }
      sCtrlVolatileList += TranslateString(g_oVolatileKeyControllers[k]);
   }
   if (sCtrlVolatileList.length > 0)
   {
      g_oVSSA.showSubHeader(sCtrlVolatileList);
   }
   else
   {
   	// When no controllers are detected, g_oVSSA is not defined.
   	if (IsDefined(g_oVSSA))
   	{
      	g_oVSSA.hideSubHeader();
      }
   }
}

// If has status, returns the label of the device, otherwise returns false.
function HasStatus(sCtrlID, sCode)
{
   var oDevice = GetDeviceDetails(sCtrlID, 1, null, null, null, false, false).device;
   var bHasStatus = false;
   var sControllerLabel = false;
   for (var j=0; !bHasStatus && j<oDevice.length; ++j)
   {
      if (oDevice[j].SectionName == "STATUS") {
         var oStatusCodesWarn = oDevice[j].STATUS_CODES_WARN;
         bHasStatus = oStatusCodesWarn.indexOf(sCode) != -1;
      }
   }
   if (bHasStatus)
   {
      sControllerLabel = oDevice[0].LABEL;
   }
   return sControllerLabel;
}