var AVControlSlider = AVControl.extend({

   events: {
      "change input#sliderTextInput" : "sliderTextChanged",
      "keydown input#sliderTextInput" : "numbersOnly"
   },
   
   initialize: function() {
      AVControl.prototype.initialize.call(this);
   },
   
   render: function() {
      var oSliderDiv = $('<div/>', {'class': "sliderWrapper"});
      $(this.el).append(oSliderDiv);
      this.drawSlider();
      return this;
   },
   
   getValue: function() {
      var s = '';
      s = this.$('input[name=' + this.model.get("sName") + ']').val();
      return s;
   },
   
   isValid: function() {
      var errorMessage = this.validateTextInput("sliderTextInput");
      if (errorMessage != "")
      {
         errorMessage = TranslateString(this.model.get("sName")) + ": " + TranslateString(errorMessage);
      }
      return errorMessage;
   },
   
   drawSlider: function() {
      var oSliderDiv = this.$('.sliderWrapper');
      var sName = this.model.get("sName");
      var oAttributes = this.model.get("oAttributes");
      var nDefault = parseInt(oAttributes.DEFAULT_VALUE);
      var nCurrent = parseInt(oAttributes.CURRENT_VALUE);
      if (isNaN(nCurrent))
      {
         nCurrent = nDefault;
      }
      if (isNaN(nIncrement))
      {
         nIncrement = 1;
      }

      // Create the slider
      if (this.model.get("bIsSliderValid"))
      {
         var nMin = parseInt(oAttributes.MINIMUM_VALUE);
         var nMax = parseInt(oAttributes.MAXIMUM_VALUE);
         var nIncrement = parseInt(oAttributes.INCREMENT);
      
         var oSliderInputDiv = $('<div/>', {'class': "sliderInputWrapper"});
         var oSliderInput = $('<div/>', {'class': "sliderInput", id: sName}).slider({
            range: "min",
            value: nCurrent,
   			min: nMin,
   			max: nMax,
   			step: nIncrement,
            name: sName
         });
         // Append the slider
         oSliderInputDiv.append(oSliderInput);
         oSliderDiv.append(oSliderInputDiv);
      }
      
      // Create the textbox and values
      var oSliderTextDiv = $('<div/>', { 'class': "textInputWrapper" });
      var oSliderTextInput = $('<input/>',
      {
         'id': "sliderTextInput",
         'class': "textInput popupTabbable",
         'type': "text",
         'name': sName,
         'value': nCurrent,
         'width': "45px",
         'maxlength': "3"
      });
      var oSliderTextLabel = $('<label/>',
      {
         'for': "sliderTextInput",
         'class': "textInputLabel"
      });
      var oSliderTextInfoBox = $('<label/>',
      {
         'for': "sliderTextInput",
         'class': "infoBox"
      });
      oSliderTextInfoBox.css("display", "none");
      // Append the textbox and values
      oSliderTextLabel.html(this.getTextLabel(nCurrent));
      oSliderTextDiv.append(oSliderTextInput);
      oSliderTextDiv.append(oSliderTextLabel);
      oSliderTextDiv.append(oSliderTextInfoBox);
      oSliderDiv.append(oSliderTextDiv);
      // Bind the slider slide function
      var oThis = this;
      oSliderDiv.bind("slide", function(e, ui) {
         var nValue = ui.value;
         oSliderTextInput.val(nValue);
         oSliderTextLabel.html(oThis.getTextLabel(nValue));
      });
      // Bind the slider slidestop function
      oSliderDiv.bind("slidestop", function(e, ui) {
         $('.infoBox').css("display", "none");
      });
   },

   getTextLabel: function(nValue) {
      return "";
   },
   
   sliderTextChanged: function(e) {
      this.validateTextInput(e.currentTarget.id);
   },
   
   validateTextInput: function(sID, isValid) {
      var errorMessage = "";
      var value = this.$('input[id=' + sID + ']').val();
      value = parseInt(value, '10');
      var oAttributes = this.model.get("oAttributes");
      var nMin = parseInt(oAttributes.MINIMUM_VALUE);
      var nMax = parseInt(oAttributes.MAXIMUM_VALUE);
      var nIncrement = parseInt(oAttributes.INCREMENT);
      if (isNaN(nIncrement))
      {
         nIncrement = 1;
      }
      if (isNaN(value))
      {
         this.updateTextInput(sID);
      }
      else if (value > nMax || value < nMin)
      {
         errorMessage = "STR_OUT_OF_RANGE";
      }
      else if (value%nIncrement != 0)
      {
         errorMessage = "STR_NOT_MULTIPLE_OF_N|" + nIncrement;
      }
      else
      {
         this.$('.infoBox').css("display", "none");
         this.updateSliderAndLabel(sID);
      }
      if (errorMessage != "")
      {
         this.$('.infoBox').css("display", "inline");
         this.$('.infoBox').html(TranslateString(errorMessage));
      }
      return errorMessage;
   },
   
   updateSliderAndLabel: function(sID) {
      var nValue = this.$('input[id=' + sID + ']').val();
      if (this.model.get("bIsSliderValid"))
      {
         this.$('.sliderInput').slider('value', nValue);
      }
      this.$('.textInputLabel').html(this.getTextLabel(nValue));
   },

   updateTextInput: function(sID) {
      if (this.model.get("bIsSliderValid"))
      {
         var nValue = this.$('.sliderInput').slider("value");
         this.$('input[id=' + sID + ']').val(nValue);
         this.$('.textInputLabel').html(this.getTextLabel(nValue));
      }
   },
   
   numbersOnly: function(e) {
      var key = e.which || e.keyCode;
      var isNumber = false;
      if ( !e.shiftKey && !e.altKey && !e.ctrlKey &&
         // numbers   
         key >= 48 && key <= 57 ||
         // Numeric keypad
         key >= 96 && key <= 105 ||
         // Backspace and Tab and Enter
         key == 8 || key == 9 || key == 13 ||
         // Home and End
         key == 35 || key == 36 ||
         // left and right arrows
         key == 37 || key == 39 ||
         // Del and Ins
         key == 46 || key == 45 )
      {
         isNumber = true;
      }
      return isNumber;
   }
});