var VControlDeviceSelectorGroup = AVResize.extend({
   
   className: "filterGroup",

   events: {
      "change .selectCheckBox": "onSelectCheck",
      "click .item": "onItemClick"
   },
   
   initialize: function() {
      AVResize.prototype.initialize.call(this);
      this.render();
   },
   
   render: function() {
      var sPopupTabbableClass = this.model.get('bPopupTabbable') ? ' popupTabbable' : '';
      var oModel = this.model;
      var oFilterGroupDiv = this.$el;
      var oSortList = oModel.get('oSortList');
      var sGroupName = oModel.get('sGroupName');
      var sGroupValueName;
      if (sGroupName == "STR_NONE")
      {
         sGroupValueName = "STR_FILTER_NONE";
      }
      else
      {
         sGroupValueName = oModel.get('sGroupValueName');
      }
      var oFilterGroupHeaderDiv = $('<div/>', {'class': "filterGroupHeader"});
      var sGroupLabel;
      if (sGroupName == "STR_ENCLOSURE" || sGroupName == "STR_ARRAY")
      {
         var groupDeviceSection = GetDeviceIDSection(sGroupValueName);
         if (IsDefined(groupDeviceSection))
         {
            sGroupLabel = groupDeviceSection.LABEL;
            var sDeviceType = groupDeviceSection.DEVICE_TYPE;
            if (sDeviceType != "TypeSmartArrayController")
            {               
               // Display port and box for storage enclosures when grouping by enclosures in Unassigned Drives tab. 
               sGroupLocation = groupDeviceSection.LOCATION;
               if (IsDefined(sGroupLocation))
               {
                  sGroupLabel = "STR_DEVICE_NAME_AT_LOCATION|" + TranslateString(sGroupLabel) + "|" + TranslateString(sGroupLocation);
               }
            }
         }
         else
         {
            sGroupLabel = sGroupValueName;
         }
      }
      else
      {
         sGroupLabel = sGroupValueName;
      }
      
      // Name in filter group header bar.
      var oFilterGroupNameDiv = $('<div/>', {'class':'filterGroupName'});
      oFilterGroupNameDiv.html(TranslateString(sGroupLabel));
      oFilterGroupHeaderDiv.append(oFilterGroupNameDiv);
      // Menu in filter group header bar.
      var oFilterGroupMenuDiv = $('<div/>', {'class':'filterGroupMenu'});
      oFilterGroupHeaderDiv.append(oFilterGroupMenuDiv);
      oFilterGroupDiv.append(oFilterGroupHeaderDiv);

      var oFilterGroupSortListsULID = this.id + "_ul";

      // Add Select All button.
      if (this.model.get('bEnableSelectAll'))
      {
         var oSelectCheckBoxID = this.id + "_selectAllCheckBox";
         var oSelectCheckBox = $('<input/>', {
            'id':oSelectCheckBoxID,
            'type':'checkbox',
            'class':'selectCheckBox ' + sPopupTabbableClass,
            'value':oFilterGroupSortListsULID
         });
         var oSelectLabel = $('<label/>', {
            'class':'selectCheckBoxLabel'
         });
         var oSelectSpan = $('<span/>', {
            'class':'selectText'
         });
         var oOptionsDiv = $('<div/>', {
            'class':'optionsContainer'
         });
         var nSelectAllCount = oSortList.length;
         var sSelectLabel = TranslateString("STR_SELECT_ALL") + " (" + nSelectAllCount + ")";
         oSelectSpan.html(sSelectLabel);
         oSelectLabel.append(oSelectCheckBox);
         oSelectLabel.append(oSelectSpan);
         oFilterGroupDiv.append(oOptionsDiv);
         oOptionsDiv.append(oSelectLabel);
      }

      // Add menu sections.
      var oFilterGroupSortListsUL = $('<ul/>', {
         'id':oFilterGroupSortListsULID,
         'class':"filterGroupSortLists"
      });
      var oDevices = this.model.get('oDevices');
      for ( var rIndex = 0; rIndex < oSortList.length; rIndex++ )
      {
         var sDeviceID = oDevices[oSortList[rIndex]];
         // TODO - don't use cache for now since drive status may have changed,
         // but look into marking cache as dirty after specific operations.
         //var section = GetDeviceIDSection(sDeviceID, true);
         var section = GetDeviceIDSection(sDeviceID);
         var sLabel = section.LABEL;
         var sDriveType = section.DEVICE_DRIVE_TYPE;
         var bIsSpare = sDriveType == "ATTR_VALUE_DRIVE_TYPE_SPARE" || 
                        sDriveType == "ATTR_VALUE_DRIVE_TYPE_SPARE_ROAMING" ||
                        sDriveType == "ATTR_VALUE_DRIVE_TYPE_SPARE_SHARED" ||
                        sDriveType == "ATTR_VALUE_DRIVE_TYPE_SPARE_ACTIVE";
         var sName = sGroupName == "STR_ENCLOSURE" ? section.LOCATION_BAY : section.LOCATION;
         var sDescription = section.SIZE;
         // Check which physical drive icon we should show:
         // - Non-spare Assigned
         // - Spare Assigned
         // - Unassigned
         var sControlLabel = this.model.get('sControlLabel');

         var sIconExtension = '';
         // Unassigned Drive Selectors
         if (sControlLabel == "STR_MSG_SEL_PDRIVES_FOR_ARRAY" ||
            sControlLabel == "STR_SELECT_UNASSIGNED_DRIVES")
         {
            sIconExtension = "_UNASSIGNED";
         }
         // Spare Drive Selectors
         else if (sControlLabel == "STR_MSG_SEL_SPARES")
         {
            sIconExtension = "_UNASSIGNED_SPARE";
            // If device is spare, then would be display green icon for Manage Spare Drive Selector.
            if (bIsSpare)
            {
               sIconExtension += "_SPARE";
            }
         }
         else if (sControlLabel == "STR_SELECT_ASSIGNED_DRIVES" && bIsSpare)
         {
            sIconExtension = "_ASSIGNED_SPARE";
         }
         var sIcon = section.ICON;
         var sIconLabel = "";
         var sItemTitle = TranslateString(sDescription);
         var sItemSubtitle = TranslateString(sName);
         // If Array
         if (sIcon == "ICON_SAS_ARRAY" || sIcon == "ICON_SATA_ARRAY")
         {
            sIconLabel = TranslateString(section.DEVICE_INTERFACE);
            sItemTitle = TranslateString(section.LABEL);// + "|" + section.LD_COUNT);
            sItemSubtitle = TranslateString(section.FREE_SPACE);
         }
         // If Logical Drive
         else if (sIcon == "ICON_DATA_LOGICAL_DRIVE")
         {
            sIconLabel = TranslateString(section.RAID_LEVEL);
            sItemTitle = TranslateString(section.SIZE);
            sItemSubtitle = TranslateString(section.LABEL);
         }
         // If Physical Drive
         else if (sIcon == "ICON_SAS_PHYSICAL_DRIVE" ||
                  sIcon == "ICON_SASSSD_PHYSICAL_DRIVE" ||
                  sIcon == "ICON_SATA_PHYSICAL_DRIVE" ||
                  sIcon == "ICON_SATASSD_PHYSICAL_DRIVE")
         {
            sIconLabel = TranslateString(section.DEVICE_INTERFACE);
            sItemTitle = TranslateString(sDescription);
            sItemSubtitle = TranslateString(sName);
         }
         var sIconClass = sIcon + sIconExtension;
         var oLI = $('<li/>', {
            'id': sDeviceID,
            'title': TranslateString(sLabel)
         });
         var oItemDiv = $('<a/>', {
            'href': '',
            'class': 'item' + sPopupTabbableClass
         });
         var sIconOverlayClass = 'ICON_OVERLAY_ACTIVITY_ERASING';
         var oIconDiv = $('<div/>', {'class': 'HPSSA_SPRITE linkIcon ' + sIconClass});
         var oIconLabelDiv = $('<div/>', {'class': 'iconLabel'});
         var oItemLeftDiv = $('<div/>', {'class': 'itemLeft'});
         var oItemRightDiv = $('<div/>', {'class': 'itemRight'});
         var oItemTitleDiv = $('<div/>', {'class': 'itemTitle'});
         var oItemSubtitleDiv = $('<div/>', {'class': 'itemSubtitle'});
         oItemTitleDiv.html(sItemTitle);
         if (!IsDefined(sName))
         {
            sName = sLabel;
         }
         oItemSubtitleDiv.html(sItemSubtitle);
         oItemLeftDiv.append(oIconDiv);
         oItemLeftDiv.append(oIconLabelDiv);
         oItemDiv.append(oItemLeftDiv);
         oItemDiv.append(oItemRightDiv);
         oItemDiv.append(GetClearFloatsDiv());
         var oCheckedIconDiv = $('<div/>', {
            'class': 'HPSSA_SPRITE checkedIcon'
         });
         oItemRightDiv.append(oCheckedIconDiv);
         oItemRightDiv.append(oItemTitleDiv);
         oItemRightDiv.append(oItemSubtitleDiv);
         var sStatusOverlay = section.ICON_OVERLAY_STATUS;
         var sOverlayClass = '';
         if (sStatusOverlay == "ICON_OVERLAY_STATUS_FATAL")
         {
            sOverlayClass = " ICON_OVERLAY_STATUS_FATAL";
         }
         else if (sStatusOverlay == "ICON_OVERLAY_STATUS_FAIL")
         {
            sOverlayClass = " ICON_OVERLAY_STATUS_FAIL";
         }
         else if (sStatusOverlay == "ICON_OVERLAY_STATUS_WARN")
         {
            sOverlayClass = " ICON_OVERLAY_STATUS_WARN";
         }
         else if (sStatusOverlay == "ICON_OVERLAY_STATUS_INFO")
         {
            sOverlayClass = " ICON_OVERLAY_STATUS_INFO";
         }
         var oStatusOverlayDiv = $('<div/>', {
            'class': 'HPSSA_SPRITE statusOverlay' + sOverlayClass
         });
         //oIconDiv.append(oStatusOverlayDiv);
         oIconLabelDiv.append(oStatusOverlayDiv);
         var sIconActivityClass = section.ICON_OVERLAY_ACTIVITY;
         var oIconActivityDiv = $('<div/>', {'class': 'iconActivityOverlay HPSSA_SPRITE ' + sIconActivityClass});
         oIconLabelDiv.append(oIconActivityDiv);
         oIconLabelDiv.append(sIconLabel);
         oLI.append(oItemDiv);
         /*
         if (!IsDefined(sName))
         {
            sName = sLabel;
         }
         var oLabelDiv = $('<div/>', {'class': 'label'});
         oLabelDiv.html(TranslateString(sName));
         oLI.append(oLabelDiv);
         if (IsDefined(sDescription))
         {
            var oDescDiv = $('<div/>', {'class': 'description'});
            oDescDiv.html(TranslateString(sDescription));
            oLI.append(oDescDiv);
         }*/
         oFilterGroupSortListsUL.append(oLI);
      }
      oFilterGroupDiv.append(oFilterGroupSortListsUL);
      oFilterGroupDiv.append(GetClearFloatsDiv());
      
      // Register events.
      var oViewThis = this;
      var bDisabled = !this.model.get('bEnableSelectAll');
      oFilterGroupSortListsUL.selectablessa({
         filter: "li",
         disabledDrag: bDisabled,
         selecting: function(e, ui) {
            oModel.incrementSelectingCount();
         },
         selected: function(e, ui) {
            if (oModel.incrementSelectedCount())
            {
               oViewThis.triggerChange();
            }
         },
         unselected: function(e, ui) {
            if (oModel.incrementUnselectedCount())
            {
               oViewThis.triggerChange();
            }
         },
         unselecting: function(e, ui) {
            oModel.incrementUnselectingCount();
         },
         stop: function(e, ui) {
            // Manually trigger blur to clear focus on action page since clicking inside device selector does not trigger browser blur.
            oViewThis.$el.trigger('blurPopupTabbable');
         }
      });
      
      var oCurrentValues = this.model.get("oCurrentValues");
      if (IsDefined(oCurrentValues) && oCurrentValues.length > 0)
      {
         $('li', oFilterGroupSortListsUL).each(function(index) {
            var bIsSelected = false;
            for (var i=0; !bIsSelected && i<oCurrentValues.length; ++i)
            {
               bIsSelected = $(this).attr("id") == oCurrentValues[i];
            }
            if (bIsSelected)
            {
               $(this).addClass("ui-selected");
            }
         });
      }
      this.triggerChange();
   },

   triggerChange: function() {
      // If everything's selected, make sure Select All checkbox is checked if it's enabled.
      if (this.model.get('bEnableSelectAll'))
      {
         var oCheckBox = this.$('.selectCheckBox');
         if (this.$('.ui-selected').length == this.$('.ui-selectee').length)
         {
            oCheckBox.prop('checked', true);
         }
         else
         {
            oCheckBox.prop('checked', false);
         }
      }
      this.$('.filterGroupSortLists').trigger('change_' + this.model.get('sType'));
   },
   
   groupSelectAll: function(sGroupID)
   {
      var oItems = this.$("#" + sGroupID + ' .ui-selectee');
      oItems.addClass('ui-selected');
      this.triggerChange();
   },
   
   groupClearSelection: function(sGroupID)
   {
      var oItems = this.$("#" + sGroupID + ' .ui-selectee');
      oItems.removeClass('ui-selected');
      this.triggerChange();
   },
   
   onItemClick: function(e) {
      var oCurrentTarget = e.currentTarget;
      var oParentElement = $(oCurrentTarget).context.parentElement;
      $(oParentElement).toggleClass('ui-selected');
      this.triggerChange();
      return false;
   },
   
   onSelectCheck: function(e) {
      var o = $(e.currentTarget);
      var bIsChecked = o.prop('checked');
      var sGroupID = o.val();
      if (IsDefined(bIsChecked) && bIsChecked)
      {
         this.groupSelectAll(sGroupID);
      }
      else
      {
         this.groupClearSelection(sGroupID);
      }
   }
   
});