var VDeviceConfigSummary = AVResize.extend({
   
   // 5. Triggered by AVActionOverview.
   refresh: function() {
      this.addToRefreshQueue(this.model);
   },

   postRefresh: function() {
      this.render();
      this.notifyRefreshObservers();
   },

   initialize: function() {
      AVResize.prototype.initialize.call(this);
      if (!IsDefined(this.model.get('oDevice')))
      {
         this.refresh();
      }
      else
      {
         this.render();
      }
   },
   
   render: function() {
      this.drawConfigSummary();
      return this;
   },
   
   drawConfigLine: function(oParentDiv, sIcon, sLabel, nCount, nIndents)
   {
      // Filter out 2nd level counts if they're 0.
      if (nIndents == 0 || (nIndents > 0 && nCount > 0))
      {
         nIndents = 0; // Ignore indents for now.
         var oDiv = $('<div/>', {'class':'element'});
         var sIconClass = "HPSSA_SPRITE smallIcon " + sIcon;
         var oIcon = $('<div/>', {'class':sIconClass});
         var oLabel = $('<div/>', {'class':'label'});
         oLabel.append(TranslateString(sLabel + "|" + nCount));
         oDiv.append(oIcon);
         oDiv.append(oLabel);
         oDiv.append(GetClearFloatsDiv());
         oParentDiv.append(oDiv);         
         oIcon.css('margin-left', nIndents*25+'px');
      }
   },
      
   drawConfigSummary: function() {
      var oDevice = this.model.get('oDevice');
      //var oDetailsDiv = $('<div/>', {'class': 'detailsDiv'});
      var bFound = false;
      var oConfigDiv = $('<div/>', {'class': 'summaryTree'});
      var oConfigReport = [];
      var nSmartCacheArrayCount = 0;
      for (var i=0; !bFound && i<oDevice.length; ++i)
      {
         var oSection = oDevice[i];
         var sSectionName = oSection.SectionName;
         bFound = sSectionName == "STR_CONTROLLER_CONFIGURATION";
         if (bFound)
         {
            var oSectionLabels = oSection.SectionLabels;
            for (var j=0; j<oSectionLabels.length; ++j)
            {
               var oSectionValues = oSection.SectionValues;
               var sIcon = "";
               var sLabel = "";
               var nCount = oSectionValues[j];
               var nIndent = 0;
               switch(oSectionLabels[j])
               {
                  case "ATTR_NAME_ARRAY_COUNT":
                     sIcon = "ICON_ARRAYS";
                     sLabel = "STR_DATA_ARRAYS_COUNT";
                     break;
                  case "ATTR_NAME_CACHE_ARRAY_COUNT":
                     sIcon = "ICON_ARRAYS";
                     sLabel = "STR_CACHE_ARRAYS_COUNT";
                     nIndent = 1;
                     nSmartCacheArrayCount = nCount;
                     break;
                  /*case "ATTR_NAME_LOGICAL_DRIVE_COUNT":
                     sIcon = "ICON_DATA_LOGICAL_DRIVES";
                     sLabel = "STR_LOGICAL_DRIVES_COUNT";
                     break;*/
                  case "ATTR_NAME_DATA_LOGICAL_DRIVE_COUNT":
                     sIcon = "ICON_DATA_LOGICAL_DRIVES";
                     sLabel = "STR_DATA_LOGICAL_DRIVE_COUNT";
                     nIndent = 1;
                     break;
                  case "ATTR_NAME_CACHE_LOGICAL_DRIVE_COUNT":
                     sIcon = "ICON_DATA_LOGICAL_DRIVES";
                     sLabel = "STR_CACHE_LOGICAL_DRIVE_COUNT";
                     nIndent = 1;
                     break;
                  /*case "ATTR_NAME_PHYSICAL_DRIVE_COUNT":
                     sIcon = "ICON_UNASSIGNED_DRIVES_GRAYSCALE";
                     sLabel = "STR_PHYSICAL_DRIVES_COUNT";
                     break;*/
                  case "ATTR_NAME_DATA_PHYSICAL_DRIVE_COUNT":
                     sIcon = "ICON_ASSIGNED_DRIVES";
                     sLabel = "STR_DATA_DRIVES_COUNT";
                     nIndent = 1;
                     break;
                  case "ATTR_NAME_CACHE_PHYSICAL_DRIVE_COUNT":
                     sIcon = "ICON_ASSIGNED_DRIVES";
                     sLabel = "STR_CACHE_DRIVES_COUNT";
                     nIndent = 1;
                     break;
                  case "ATTR_NAME_SPARE_PHYSICAL_DRIVE_COUNT":
                     sIcon = "ICON_SPARE_DRIVE";
                     sLabel = "STR_SPARE_DRIVES_COUNT";
                     nIndent = 1;
                     break;
                  case "ATTR_NAME_UNASSIGNED_PHYSICAL_DRIVE_COUNT":
                     sIcon = "ICON_UNASSIGNED_DRIVES";
                     sLabel = "STR_UNASSIGNED_DRIVES_COUNT";
                     nIndent = 1;
                     break;
               }
               if (sIcon != '')
               {
                  oConfigReport.push({
                     'sIcon': sIcon,
                     'sLabel': sLabel,
                     'nCount': nCount,
                     'nIndent': nIndent
                  })
               }
            }
         }
      }
      if (bFound)
      {
         for (var i=0; i<oConfigReport.length; ++i)
         {
            var sIcon = oConfigReport[i].sIcon;
            var sLabel = oConfigReport[i].sLabel;
            var nCount = oConfigReport[i].nCount;
            var nIndent = oConfigReport[i].nIndent;
            if (sLabel == "STR_DATA_ARRAYS_COUNT")
            {
               // Get number of data arrays count. Currently the arrays count
               // contains the sum of data arrays and SmartCache arrays.
               // TODO: Update SOULAPI to provide the data arrays count.
               nCount -= nSmartCacheArrayCount;
            }
            this.drawConfigLine(oConfigDiv, sIcon, sLabel, nCount, nIndent);
         }
         this.$el.append(oConfigDiv);
         // View more details.
         var oLink = $('<a/>', {
            'href':'',
            'id':'viewMoreDetails',
            'class':'widgetLink'
         });
         oLink.append(TranslateString("STR_VIEW_MORE_DETAILS"));
         this.$el.append(oLink);
         //oDetailsDiv.append(oStatusDiv);
         //this.$el.append(oDetailsDiv);
      }
      else
      {
         this.model.set({'bConfigSummaryExists':false});
      }
   }
   
});

_.defaults(VDeviceConfigSummary.prototype, MixinRefreshObserver());
_.defaults(VDeviceConfigSummary.prototype, MixinRefreshSubject());