var VDeviceDetails = AVResize.extend({

   events: {
      "click .deviceLink":"clickDeviceLink"
   },
   
   initialize: function() {
      AVResize.prototype.initialize.call(this);
      this.oVDeviceStatus = null;
      this.render();
   },
   
   render: function() {
      var oDevice = this.model.get('oDevice');
      this.drawDetails(oDevice);
      return this;
   },
   
   drawDetails: function(o) {
      var oDetailsDiv = $('<div/>', {'class': 'detailsDiv'});
      var oSectionsUL = $('<ul/>', {'class': 'sections'});
      for (var i=0; i<o.length; ++i)
      {
         this.drawDetailsSection(o[i].SectionName, o[i].SectionLabels, o[i].SectionValues, oSectionsUL);
      }
      // Add status alerts.
      var bIncludeStatusAlerts = this.model.get('bIncludeStatusAlerts');
      if (bIncludeStatusAlerts)
      {
         var oMDeviceStatus = new MDeviceStatus({
            'oDevice': o,
            'nDetailLevel': 2
         });
         this.oVDeviceStatus = new VDeviceStatus({
            'model':oMDeviceStatus
         });
         var oSectionLI = $('<li/>', {'class': 'section'});
         oSectionLI.append(this.oVDeviceStatus.$el);
         oSectionsUL.append(oSectionLI);
      }
      oDetailsDiv.append(oSectionsUL);
      this.$el.append(oDetailsDiv);
   },

   getLabel: function(bIncludeDeviceLinks, sData, sPrefix, bIncludeDriveType) {
      var nLastIndex = sData.lastIndexOf("|");
      var sDeviceID = sData.substring(nLastIndex + 1);
      var sLabel = sData.substring(0, nLastIndex);
      var oLabelWrapper = $('<div/>');
      var oLabel;
      sLabel = TranslateString(sLabel);
      if (IsDefinedAndSet(sPrefix))
      {
         oLabelWrapper.append(TranslateString(sPrefix) + ": ");
      }
      if (bIncludeDeviceLinks)
      {
         oLabel = $('<a/>', {
            'href': '',
            'class': 'deviceLink popupTabbable',
            'id': sDeviceID
         });
         if (bIncludeDriveType)
         {
            var section = GetDeviceIDSection(sDeviceID);
            var sDriveType = section.DEVICE_DRIVE_TYPE;
            sLabel += " (" + TranslateString(sDriveType) + ")";
         }
         oLabel.append(sLabel);
      }
      else
      {
         oLabel = sLabel;
      }
      oLabelWrapper.append(oLabel);
      return oLabelWrapper;
   },
   
   drawDetailsSection: function(sSectionName, oLabels, oValues, oSectionsUL) {
      var sDetails = this.model.get('sDetails');
      if (sSectionName != "STR_LESS_INFO" && 
          sSectionName != "STATUS" && 
          sSectionName != "L0" &&
          (sDetails == '' || sDetails == sSectionName))
      {
         if (oLabels.length > 0) {
            var oSectionLI = $('<li/>', {'class': 'section'});
            var oSectionNameDiv = $('<div/>', {
               'class': 'sectionName'
            });
            oSectionNameDiv.html(TranslateString(sSectionName));
            oSectionLI.append(oSectionNameDiv);
            var oSectionDetailsTable = $('<table/>', {
               'class': 'sectionDetails'
            });
            for (var j=0; j<oLabels.length; ++j)
            {
               var sLabel = oLabels[j];
               var sValue = oValues[j];
               var sLastTRClass = j == oLabels.length-1 ? 'lastTR' : '';
               var oTR = $('<tr/>', {'class': sLastTRClass});
               var bIncludeDeviceLinks = this.model.get('bIncludeDeviceLinks');
               var oLabelTD = $('<td/>', {'class': 'label'});
               var oDataTD = $('<td/>', {'class': 'data'});
               var oLabelContent = '';
               var bHasData = true;
               if (sSectionName == "STR_LOGICAL_DRIVES")
               {
                  oLabelContent = this.getLabel(bIncludeDeviceLinks, sLabel);
                  oDataTD.append(TranslateString(sValue));
               }
               else if (sSectionName == "STR_PHYSICAL_DRIVES" ||
                        sSectionName == "STR_DEVICE_PATH" ||
                        sSectionName == "STR_STORAGE_ENCLOSURES" ||
                        sSectionName == "STR_TAPE_DEVICES")
               {
                  oLabelContent = this.getLabel(bIncludeDeviceLinks, sLabel);
                  bHasData = false;
               }
               else if (sSectionName == "STR_SPARE_DRIVES")
               {
                  oLabelContent = this.getLabel(bIncludeDeviceLinks, sLabel, '', true);
                  bHasData = false;
               }
               else if (sSectionName == "STR_FAILED_DRIVES")
               {
                  oLabelContent = this.getLabel(bIncludeDeviceLinks, sLabel);
                  // Display assigned spare info if available.
                  if (IsDefinedAndSet(sValue))
                  {
                     oDataTD.append(this.getLabel(bIncludeDeviceLinks, sValue, "GUI_NAME_MAPPED_SPARE_DRIVE"));
                  }
               }
               else
               {
                  oLabelContent = TranslateString(sLabel);
                  if (sLabel == "GUI_NAME_MAPPED_SPARE_DRIVE")
                  {
                     oDataTD.append(this.getLabel(bIncludeDeviceLinks, sValue));
                  }
                  else
                  {
                     oDataTD.append(TranslateString(sValue));
                  }
               }
               oLabelTD.append(oLabelContent);
               oTR.append(oLabelTD);
               if (bHasData)
               {
                  oTR.append(oDataTD);
               }
               else
               {
                  oLabelTD.attr('colspan', 2);
               }
               oSectionDetailsTable.append(oTR);
            }
            oSectionLI.append(oSectionDetailsTable);
            oSectionsUL.append(oSectionLI);
            oSectionNameDiv.click(function() {
               oSectionDetailsTable.toggle();
            });
         }
      }
   },

   getStatusSection: function(title, countVar, codesVar, messagesVar) {
      var sectionStr = "";
      if ( countVar > 0 )
      {
         sectionStr += "<tr class=\"noBorder\"><th colspan=\"3\" align=\"left\">" + title + "</th></tr>";
         for ( var i = 0; i < countVar; i++ )
         {
            var sClass = '';
            if (i == countVar - 1)
            {
               sClass = ' class="noBorder"';
            }
            sectionStr += "<tr" + sClass + "><td></td><td class='code' valign=\"top\">" + codesVar[i] + "</td><td>" + TranslateStatusMessage(messagesVar[i]) + "</td></tr>";
         }    
      }
      return sectionStr;
   },

   scrollToStatus: function() {
      if (IsDefined(this.oVDeviceStatus))
      {
         this.$el.scrollTop(0); // Reset scroll to top of container to obtain the correct positioning of the status section.
         this.$el.scrollTo(
            this.oVDeviceStatus.el, 
            this.oVDeviceStatus.el,
            {
               gap: {
                  x:0,
                  y:-151 // 75 (Top positioning of popup) + 61 (Popup header height+border) + 15 (padding above section title)
               }
            });
      }
   },

   clickDeviceLink: function(e) {
      var sDeviceID = e.currentTarget.id;
      var oDevice = GetDeviceDetails(sDeviceID).device;
      this.model.set({
         'sDeviceID': sDeviceID,
         'oDevice': oDevice
      });
      return false;
   },

   resizeHeight: function() {
      AVResize.prototype.resizeHeight.call(this);
   }
   
});