var VDeviceStatus = AVResize.extend({
   
   // 5. Triggered by AVActionOverview.
   refresh: function() {
      this.addToRefreshQueue(this.model);
   },

   postRefresh: function() {
      this.render();
      this.notifyRefreshObservers();
   },

   initialize: function() {
      AVResize.prototype.initialize.call(this);
      if (!IsDefined(this.model.get('oDevice')))
      {
         this.refresh();
      }
      else
      {
         this.render();
      }
   },
   
   render: function() {
      this.drawStatus();
      return this;
   },

   drawCounts: function(oParentDiv, nCritical, nWarn, nInfo, nTask) {
      var sCriticalClass = nCritical > 0 ? "criticalActive" : "criticalInactive";
      var sWarnClass = nWarn > 0 ? "warnActive" : "warnInactive";
      var sInfoClass = nInfo > 0 ? "infoActive" : "infoInactive";
      var sTaskClass = nTask > 0 ? "taskActive" : "taskInactive";
      
      // Add Status Alert Counts Table
      var oSectionAlertsTable = $('<table/>', {'class': 'sectionAlerts'});
      var oTR = $('<tr/>');
      var oTD = $('<td/>', {'class': 'statusCounts'});
      var s = 
         '<div class="statusIcon ' + sCriticalClass + ' HPSSA_SPRITE"></div><div class="value">' + nCritical + '</div>' +
         '<div class="statusIcon ' + sWarnClass + ' HPSSA_SPRITE"></div><div class="value">' + nWarn + '</div>' +
         '<div class="statusIcon ' + sInfoClass + ' HPSSA_SPRITE"></div><div class="value">' + nInfo + '</div>' +
         '<div class="statusIcon ' + sTaskClass + ' HPSSA_SPRITE"></div><div class="value">' + nTask + '</div>';
      oTD.html(s);
      oTR.append(oTD);
      oSectionAlertsTable.append(oTR);
      oParentDiv.append(oSectionAlertsTable);
   },
   
   drawStatus: function() {
      this.$el.empty();
      var oDevice = this.model.get('oDevice');
      var nDetailLevel = this.model.get('nDetailLevel');
      //var oDetailsDiv = $('<div/>', {'class': 'detailsDiv'});
      var bFound = false;
      for (var i=0; !bFound && i<oDevice.length; ++i)
      {
         var sSectionName = oDevice[i].SectionName;
         bFound = sSectionName == "STATUS";
         if (bFound)
         {
            var oStatus = oDevice[i];
            var oStatusDiv = $('<div/>', {'class': 'statusDiv'});
            var oUL = $('<ul/>', {'class': 'sections'});
            var oLI = $('<li/>', {'class': 'section'});
            
            // Calculate counts.
            var nFail = oStatus.STATUS_COUNT_FAIL;
            var nFatal = oStatus.STATUS_COUNT_FATAL;
            var nWarn = oStatus.STATUS_COUNT_WARN;
            var nInfo = oStatus.STATUS_COUNT_INFO;
            var nTask = oStatus.STATUS_COUNT_TASKS;
            var nCritical = parseInt(nFail) + parseInt(nFatal);
            var nTotal = oStatus.STATUS_COUNT_TOTAL;
            
            this.drawCounts(oLI, nCritical, nWarn, nInfo, nTask);
            
            // Add Status Alert Messages.
            //var oMsgs = $('<table/>', {'class': 'sectionMessages'});
            var oMsgs = $('<div/>', {'class': 'sectionMessages'});
            var fatalCodes = oStatus.STATUS_CODES_FATAL.split("|");
            var fatalMessages = oStatus.STATUS_MESSAGES_FATAL.split("||");
            var failCodes = oStatus.STATUS_CODES_FAIL.split("|");
            var failMessages = oStatus.STATUS_MESSAGES_FAIL.split("||");
            var warnCodes = oStatus.STATUS_CODES_WARN.split("|");
            var warnMessages = oStatus.STATUS_MESSAGES_WARN.split("||");
            var infoCodes = oStatus.STATUS_CODES_INFO.split("|");
            var infoMessages = oStatus.STATUS_MESSAGES_INFO.split("||");
            var taskCodes = oStatus.STATUS_CODES_TASKS.split("|");
            var taskMessages = oStatus.STATUS_MESSAGES_TASKS.split("||");
            // Add Fatal Messages.
            this.drawStatusSection(oMsgs, TranslateString("STR_GUI_FATAL_ERRORS"), "ICON_OVERLAY_STATUS_FATAL", nFatal, fatalCodes, fatalMessages);
            // Add Fail/Critical Messages.
            this.drawStatusSection(oMsgs, TranslateString("STR_GUI_CRITICAL_MESSAGES"), "ICON_OVERLAY_STATUS_FATAL", nFail, failCodes, failMessages);
            if (nDetailLevel > 1)
            {
               // Add Warn Messages.
               this.drawStatusSection(oMsgs, TranslateString("STR_GUI_WARNINGS"), "ICON_OVERLAY_STATUS_WARN", nWarn, warnCodes, warnMessages);
               // Add Info Messages.
               this.drawStatusSection(oMsgs, TranslateString("STR_GUI_INFORMATION_MESSAGES"), "ICON_OVERLAY_STATUS_INFO", nInfo, infoCodes, infoMessages);
            }
            // Add Task Messages.
            this.drawStatusSection(oMsgs, TranslateString("STR_GUI_ACTIVE_TASKS"), "ICON_OVERLAY_STATUS_TASK", nTask, taskCodes, taskMessages);
            if (nTotal > 0 && 
               (nDetailLevel > 1 || (nDetailLevel == 1 && (nCritical + nTask) > 0)))
            {
               oLI.append(oMsgs);
            }
            oUL.append(oLI);
            oStatusDiv.append(oUL);
         }
      }
      //oDetailsDiv.append(oStatusDiv);
      //this.$el.append(oDetailsDiv);
      
      if (nDetailLevel > 1)
      {
         var oSectionNameDiv = $('<div/>', {'id': 'statusSection', 'class': 'sectionName'});
         oSectionNameDiv.html(TranslateString("STR_STATUS_MESSAGES"));
         this.$el.append(oSectionNameDiv);
      }
      
      this.$el.append(oStatusDiv);
      
      // View more details.
      if (nDetailLevel == 1)
      {
         var oLink = $('<a/>', {
            'href':'',
            'id':'viewStatusMessages',
            'class':'widgetLink'
         });
         oLink.html(TranslateString("STR_VIEW_ALL_STATUS_MESSAGES"));
         this.$el.append(oLink);
      }
   },
   
   drawStatusSection: function(oParentDiv, sTitle, sIcon, countVar, codesVar, messagesVar) {
      if (countVar > 0)
      {
         var oSectionDiv = $('<div/>', {'class':'section'});
         var oSectionTable = $('<table/>', {'class':'section'});
         var oTitleDiv = $('<div/>', {'class':'sectionTitle'});
         var sIconClass = 'icon HPSSA_SPRITE ' + sIcon;
         var oIconDiv = $('<div/>', {'class':sIconClass});
         var oNameDiv = $('<div/>', {'class':'name'});
         oNameDiv.append(TranslateString(sTitle));
         oTitleDiv.append(oIconDiv);
         oTitleDiv.append(oNameDiv);
         oSectionDiv.append(oTitleDiv);
         for ( var i = 0; i < countVar; ++i )
         {
            var sTRClass = 'row';
            if (i == countVar - 1)
            {
               sTRClass += ' last';
            }
            var oRowTR = $('<tr/>', {'class':sTRClass});
            
            // Add Icon
            /*var sIconClass = 'icon HPSSA_SPRITE SMALL ' + sIcon;
            var oIconTD = $('<td/>', {'class':'icon', 'valign':'top'});
            var oIconDiv = $('<div/>', {'class':sIconClass});
            oIconTD.append(oIconDiv);
            oRowTR.append(oIconTD);*/

            var oCodeTD = $('<td/>', {'class':'code', 'valign':'top'});
            oCodeTD.append(codesVar[i]);
            oRowTR.append(oCodeTD);

            // Add Message
            var oMsgTD = $('<td/>', {'class':'msg', 'valign':'top'});
            oMsgTD.html(TranslateStatusMessage(messagesVar[i]));
            oRowTR.append(oMsgTD);
            oSectionTable.append(oRowTR);
         }
         oSectionDiv.append(oSectionTable);
         oParentDiv.append(oSectionDiv);
         oTitleDiv.click(function() {
            oSectionTable.toggle();
         });

      }
   }
   
});

_.defaults(VDeviceStatus.prototype, MixinRefreshObserver());
_.defaults(VDeviceStatus.prototype, MixinRefreshSubject());
