var VDeviceStatusCounts = AVResize.extend({
   
   initialize: function() {
      AVResize.prototype.initialize.call(this);
      this.model.bind("change:nTimeUpdated", this.refreshCompleted, this);
      if (this.model.get('nTimeUpdated') > 0)
      {
         this.render();
      }
   },
   
   refresh: function() {
      this.model.refresh();
   },
   
   refreshCompleted: function() {
      this.trigger("refreshCompleted");
      this.render();
   },
   
   render: function() {
      this.drawStatus();
      return this;
   },

   drawCounts: function(oParentDiv, nCritical, nWarn, nInfo, nTask) {
      var sCriticalClass = nCritical > 0 ? "criticalActive" : "criticalInactive";
      var sWarnClass = nWarn > 0 ? "warnActive" : "warnInactive";
      var sInfoClass = nInfo > 0 ? "infoActive" : "infoInactive";
      var sTaskClass = nTask > 0 ? "taskActive" : "taskInactive";
      
      // Add Status Alert Counts Table
      var oSectionAlertsTable = $('<table/>', {'class': 'sectionAlerts'});
      var oTR = $('<tr/>');
      var oTD = $('<td/>', {'class': 'statusCounts'});
      var s = 
         '<div class="statusIcon ' + sCriticalClass + ' HPSSA_SPRITE"></div><div class="value">' + nCritical + '</div>' +
         '<div class="statusIcon ' + sWarnClass + ' HPSSA_SPRITE"></div><div class="value">' + nWarn + '</div>' +
         '<div class="statusIcon ' + sInfoClass + ' HPSSA_SPRITE"></div><div class="value">' + nInfo + '</div>' +
         '<div class="statusIcon ' + sTaskClass + ' HPSSA_SPRITE"></div><div class="value">' + nTask + '</div>';
      oTD.html(s);
      oTR.append(oTD);
      oSectionAlertsTable.append(oTR);
      oParentDiv.append(oSectionAlertsTable);
   },
   
   drawStatus: function() {
      this.$el.empty();
      var oDevice = this.model.get('oDevice');
      var nDetailLevel = this.model.get('nDetailLevel');
      //var oDetailsDiv = $('<div/>', {'class': 'detailsDiv'});
      var bFound = false;
      var nTotalCount = 0;
      for (var i=0; !bFound && i<oDevice.length; ++i)
      {
         var sSectionName = oDevice[i].SectionName;
         bFound = sSectionName == "STATUS";
         if (bFound)
         {
            var oStatus = oDevice[i];
            var oStatusDiv = $('<div/>', {'class': 'statusDiv'});
            var oUL = $('<ul/>', {'class': 'sections'});
            var oLI = $('<li/>', {'class': 'section'});
            
            // Calculate counts.
            var nFail = oStatus.STATUS_COUNT_FAIL;
            var nFatal = oStatus.STATUS_COUNT_FATAL;
            var nWarn = oStatus.STATUS_COUNT_WARN;
            var nInfo = oStatus.STATUS_COUNT_INFO;
            var nTask = oStatus.STATUS_COUNT_TASKS;
            var nCritical = parseInt(nFail) + parseInt(nFatal);
            var nTotal = oStatus.STATUS_COUNT_TOTAL;
            nTotalCount += nTotal;
            this.drawCounts(oLI, nCritical, nWarn, nInfo, nTask);
            oUL.append(oLI);
            oStatusDiv.append(oUL);
         }
      }
      
      this.$el.append(oStatusDiv);
      
      // Link to status section.
      if (nTotalCount > 0)
      {
         var oScrollToStatusLink = $('<a/>', {
            'href':'',
            'id':'viewStatusMessages',
            'class':'widgetLink popupTabbable'
         });
         /*var oScrollToStatusLink = $('<a/>', {
            'href':'#',
            'class':'widgetLink'
         });*/
         oScrollToStatusLink.html(TranslateString("STR_VIEW_STATUS_MESSAGES"));
         if (!this.model.get('bNoClickAction'))
         {
            var oThis = this;
            oScrollToStatusLink.click(function(){
               oThis.trigger("scrollToStatus");
               return false;
            });
         }
         this.$el.append(oScrollToStatusLink);
      }
   }
   
});