function MixinRefreshObserver() 
{
   return {
      // Stores the objects to be refreshed when executeRefreshQueue is called.
      oRefreshQueue: [],

      // Adds an object to the refresh queue to be refreshed when executeRefreshQueue is called.
      addToRefreshQueue: function() {
         for (var i=0; i<arguments.length; ++i)
         {
            if (IsDefinedAndSet(arguments[i]))
            {
               this.oRefreshQueue.push(arguments[i]);
            }
         }
         this.executeRefreshQueue();
      },

      // Calls refresh on objects in the refresh queue, one at a time.
      executeRefreshQueue: function() {
         if (this.oRefreshQueue.length > 0)
         {
            var o = this.oRefreshQueue[0];
            // Remove the refreshed object from the refresh queue.
            this.oRefreshQueue.splice(0, 1);
            o.once('refreshCompleted', this.updateRefresh, this);
            o.refresh();
         }
         else
         {
            this.postRefresh();
         }
      },

      // Called after each object in the refresh queue is refreshed.
      updateRefresh: function() {
         if (this.oRefreshQueue.length > 0)
         {
            this.executeRefreshQueue();
         }
         else
         {
            this.postRefresh();
         }
      },

      // Called after every object in the refresh queue is refreshed.
      postRefresh: function() {
         // To overload.
      }
   }
};