var AVPopupContent = AVResize.extend({
   
   className: "popupContent",

   events: {
      'click .button.pianoButton.Dismiss.op': 'onDismiss'
   },

   initialize: function() {
      AVResize.prototype.initialize.call(this);
      this.oVPopupHeader = null;
      this.oVPopupBody = null;
      this.render();
   },

   dispose: function() {
      if (IsDefined(this.oVPopupHeader))
      {
         this.oVPopupHeader.dispose();
         this.oVPopupHeader = null;
      }
      // Begin longest section.
      if (IsDefined(this.oVPopupBody))
      {
         this.oVPopupBody.dispose();
         this.oVPopupBody = null;
      }
      // End longest section.
      if (IsDefined(this.oVDeviceStatusCounts))
      {
         this.oVDeviceStatusCounts.dispose();
         this.oVDeviceStatusCounts = null;
      }
      AVResize.prototype.dispose.call(this);
   },

   onDismiss: function() {
      this.$el.trigger("closePopup");
      return false;
   },

   // ENTER keyboard control will trigger a click on the default button.
   onDefault: function(e) {
      var oBtn = this.getDefaultButtons();
      if (oBtn.length == 1)
      {
         oBtn.click();
      }
   },

   // Action popups will overload this.
   getDefaultButtons: function() {
      return this.$('.default');
   },

   showLoadingIcon: function() {
      var oLoading = this.$('.loading');
      // Empty and append the DIV each time we want to show the
      // loading icon so that the icon in IE LTE 9 will animate.
      var oIconDiv = $('<div/>',{'class':'HPSSA_ICON_LOADING HPSSA_SPRITE'});
      oLoading.empty().append(oIconDiv);
   },

   hideLoadingIcon: function() {
      // Enable hot keys.
      this.$('.buttons').show();
      this.$('.loading').empty();
   },

   drawHeader: function(sLabel, sIconClass) {
      var oHeaderDiv = $('<div/>', { 'class': 'popupHeader' });
      var sTitle = this.model.get('sTitle');;
      var oOptions = {
         'bIsPopup': true,
         'sTitle': sTitle
      };
      if (IsDefined(sLabel))
      {
         oOptions['sLabel'] = TranslateString(sLabel);
      }
      else
      {
         oOptions['sDeviceID'] = this.model.get('sDeviceID');
      }
      if (IsDefined(sIconClass)) 
      {
         oOptions['sIconClass'] = sIconClass;
      }
      var oMHeader = new MHeader(oOptions);
      this.oVPopupHeader = new VHeader({
         'model': oMHeader,
         'el': oHeaderDiv
      });
      this.$el.append(oHeaderDiv);
      return oHeaderDiv;
   },

   drawHeaderNav: function(oHeader) {
      var oNavDiv = $('<div/>', { 'class': 'headerNavDiv' });
      var oNavForward = $('<a/>', {
         'href':'',
         'class': 'popupTabbable navButton navForward disabled',
         'id': 'navForward',
         'title':TranslateString("HELP_FORWARD")
      });
      var oNavForwardSprite = $('<div/>', {
         'class': 'HPSSA_SPRITE'
      });
      oNavForward.append(oNavForwardSprite);
      var oNavBackward = $('<a/>', {
         'href':'',
         'class': 'popupTabbable navButton navBackward disabled',
         'id': 'navBackward',
         'title':TranslateString("HELP_BACK")
      });
      var oNavBackwardSprite = $('<div/>', {
         'class': 'HPSSA_SPRITE'
      });
      oNavBackward.append(oNavBackwardSprite);
      oNavDiv.append(this.getDividerDiv());
      oNavDiv.append(oNavBackward);
      oNavDiv.append(this.getDividerDiv());
      oNavDiv.append(oNavForward);
      oHeader.append(oNavDiv);
      return oNavDiv;
   },

   drawFooter: function() {
      var oFooter = $('<div/>', { 'class': 'popupFooter' });
      var oInfoDiv = $('<div/>', { 'class':"info" });
      var oCloseButton = $('<a/>', { 
         'href': '',
         'class': 'button pianoButton op default Dismiss popupTabbable' 
      });
      oCloseButton.append(TranslateString("STR_CLOSE"));
      var oButtons = $('<div/>', { 'class': 'buttons' });
      oButtons.append(oCloseButton);
      oFooter.append(oInfoDiv);
      oFooter.append(oButtons);
      this.$el.append(oFooter);
   },

   drawFooterInfoSection: function(sLabel, sValue) {
      var oInfoDiv = this.$('.popupFooter .info');
      var oSectionDiv = $('<div/>', {
         'class':'section'
      });
      var oLabelSpan = $('<span/>', {
         'class':'label'
      });
      var oValueSpan = $('<span/>', {
         'class':'value'
      });
      oLabelSpan.html(TranslateString(sLabel) + ": ");
      oValueSpan.html(TranslateString(sValue));
      oSectionDiv.append(oLabelSpan);
      oSectionDiv.append(oValueSpan);
      oInfoDiv.append(oSectionDiv);
   },

   getDividerDiv: function() {
      var oDividerDiv = $('<div/>', {
         'class':'helpHeaderDivider'
      });
      return oDividerDiv;
   },

   resizeHeight: function() {
      AVResize.prototype.resizeHeight.call(this);
      var nHeight = getPopupHeight(); //this.model.get('nHeight');
      var nMaxHeight = this.model.get('nMaxHeight');
      var bUseMaxHeight = this.model.get('bUseMaxHeight');
      if (bUseMaxHeight || nHeight > nMaxHeight)
      {
         nHeight = nMaxHeight;
         var oPopupHeader = this.$('.popupHeader');
         var oPopupFooter = this.$('.popupFooter');
         var nBodyHeight = nHeight;
         if (IsDefined(oPopupHeader))
         {
            nBodyHeight -= oPopupHeader.outerHeight();
         }
         if (IsDefined(oPopupFooter))
         {
            nBodyHeight -= oPopupFooter.outerHeight();
         }
         this.oVPopupBody.model.set('nHeight', nBodyHeight);
      }
   }
});