var VMainMenuPopup = AVPopupContent.extend({
   
   render: function() {
      var oMMainMenu = new MMainMenu({
         'sSelected': this.model.get('sSelected'),
         'oControllerList': this.model.get('oControllerList')
      });
      this.oVPopupBody = new VMainMenu({
         'className':'popupMenu',
         'model':oMMainMenu
      });
      this.$el.append(this.oVPopupBody.$el);

      return this;
   }

});

var VMainMenu = AVResize.extend({
   
   id: 'hp-main-menu',

   initialize: function() {
      AVResize.prototype.initialize.call(this);
      this.render();
   },

   render: function() {
      var oSectionsUL = $('<ul/>', {'class':'hp-sections'});
      // HP Smart Storage Administrator
      var oDevicesSectionLIUL = this.drawMenuSectionLI(oSectionsUL, "STR_HOME");
      if (isDiagnosticsSupported())
      {
         // Draw Server
         var oHomeLinkLI = this.drawMenuSectionLinkLI("home/server/server", "STR_HP_PROLIANT", "server");
         oDevicesSectionLIUL.append(oHomeLinkLI);
         // Draw Proliant tasks
         var oProliantSectionLIUL = this.drawMenuActionSectionLI(oSectionsUL, "STR_HP_PROLIANT", "server");
         var oProliantDiagnoseLinkLI = this.drawMenuActionSectionLinkLI("diagnostics/server", "STR_DIAGNOSE", sID);
         oProliantSectionLIUL.append(oProliantDiagnoseLinkLI);
      }
      // Draw everything else
      var oControllerList = this.model.get('oControllerList');
      for (var i=0; i<oControllerList.length; ++i) {
         var sID = oControllerList[i];
         // Draw Devices Link
         var sLink = "home/arraycontroller/" + encodeURIComponent(sID);
         // Get allowed tasks
         var oResult = EnumerateAllowedDeviceTasks(sID);
         var oAllowedTasks = oResult.RequestResult;
         var sLabel = oResult.LABEL;
         var oCtrlLinkLI = this.drawMenuSectionLinkLI(sLink, sLabel, sID);
         oDevicesSectionLIUL.append(oCtrlLinkLI);
         // Draw tasks for each controller, but hide them
         var oTasksSectionLIUL = this.drawMenuActionSectionLI(oSectionsUL, sLabel, sID);
         for (var j=0; j<oAllowedTasks.length; ++j) {
            var sTask = oAllowedTasks[j];
            if (sTask == "SALTaskConfiguration") {
               var oConfigureLinkLI = this.drawMenuActionSectionLinkLI("configuration/" + encodeURIComponent(sID), "STR_CONFIGURE", sID);
               oTasksSectionLIUL.append(oConfigureLinkLI);
            }
            else if (isDiagnosticsSupported() && sTask == "SALTaskDiagnostics") {
               var oDiagnoseLinkLI = this.drawMenuActionSectionLinkLI("diagnostics/" + encodeURIComponent(sID), "STR_DIAGNOSE", sID);
               oTasksSectionLIUL.append(oDiagnoseLinkLI);
            }
         }
      }
      this.$el.append(oSectionsUL);
      return this;
   },

   drawMenuSectionLI: function(oSectionsUL, sLabel, sID) {
      var sHovered = '';
      if (IsDefinedAndSet(this.model.get('sSelected'))) {
         sHovered = ' hovered';
      }
      var oLI = $('<li/>', {
         'class': 'main-menu-tabs' + sHovered
      });
      var oLabel = $('<div/>', {
         'class': 'label'
      });
      var oSectionLIUL = $('<ul/>', {
         'class': 'hp-section'
      });
      oLI.append(oLabel);
      oLI.append(oSectionLIUL);
      oLabel.append(TranslateString(sLabel).toUpperCase());
      oSectionsUL.append(oLI);
      return oSectionLIUL;
   },

   drawMenuActionSectionLI: function(oSectionsUL, sLabel, sID) {
      var oLI = $('<li/>', {
         'class': 'main-menu-actions',
         'id': sID
      });
      var oLabel = $('<div/>', {
         'class': 'label'
      });
      var oSectionLIUL = $('<ul/>', {
         'class': 'hp-section'
      });
      oLI.append(oLabel);
      oLI.append(oSectionLIUL);
      oLabel.append(TranslateString(sLabel).toUpperCase());
      oSectionsUL.append(oLI);
      var sSelected = this.model.get('sSelected');
      if (sID != sSelected) {
         oLI.hide();
      }
      return oSectionLIUL;
   },

   drawMenuSectionLinkLI: function(sLink, sLabel, sID) {
      var oThis = this;
      var oLI = $('<li/>');
      var oDiv = $('<a/>', {
         'href': '#' + sLink,
         'class': "main-menu-tab popupTabbable",
         'id': sID
      });
      if (sLink.indexOf(oThis.model.get('sSelected')) != -1)
      {
         oDiv.addClass('hovered');
      }
      oDiv.append(TranslateString(sLabel));
      oLI.append(oDiv);
      oDiv.mouseenter(function(e) {
         oThis.menuTabHover(e, oThis)
      });
      return oLI;
   },

   drawMenuActionSectionLinkLI: function(sLink, sLabel, sID) {
      var oLI = $('<li/>');
      var oA = $('<a/>', {
         'href': '#' + sLink,
         'class': "main-menu-a popupTabbable"
      });
      if (sLink.indexOf("configuration") == -1 &&
          sLink.indexOf("diagnostics") == -1)
      {
         if (sLink.indexOf(this.model.get('sSelected')) != -1)
         {
            oA.addClass('hp-selected');
         }
      }
      oA.append(TranslateString(sLabel));
      oLI.append(oA);
      return oLI;
   },

   menuTabHover: function(e, oThis) {
      oThis.$('.main-menu-tabs').addClass('hovered');
      var oTabs = oThis.$('.main-menu-tab');
      for (var i=0; i<oTabs.length; ++i) {
         $(oTabs[i]).removeClass('hovered');
      }
      var oHoveredTab = $(e.currentTarget);
      oHoveredTab.addClass('hovered');
      oThis.showMenuActions(e.currentTarget.id, oThis);
   },

   showMenuActions: function(sID, oThis) {
      var oActions = oThis.$('.main-menu-actions');
      for (var i=0; i<oActions.length; ++i) {
         var sActionsID = oActions[i].id;
         if (sID == sActionsID) {
            $(oActions[i]).show();
         }
         else {
            $(oActions[i]).hide();
         }
      }
   }
});